@@ -14,4 +14,4 @@
 #include "MsXpS/libXpertMassGui/ScriptingObjectTreeWidgetItem.hpp"
 #include "MsXpS/libXpertMassGui/ScriptingWnd.hpp"
 #include "MsXpS/libXpertMassGui/ToleranceWidget.hpp"
-#include "MsXpS/libXpertMassGui/XpertMassGuiJsQml.hpp"
+#include "MsXpS/libXpertMassGui/XpertMassGuiJavaScript.hpp"
