@@ -497,7 +497,7 @@ ChemicalGroup::findRuleByEntityAndName(const QString &entity,
 
 /*!
 \brief Validates this instance, setting eventual error messages in \a
-error_list.
+error_list_p.
 
 \note \a error_list_p is not cleared.
 
