@@ -277,6 +277,12 @@ CleavageAgent::~CleavageAgent()
 {
 }
 
+/*!
+\brief Initialized this CleavageAgent using \a other.
+
+After initialization, validity is checked, the result is set to m_isValid and is
+returned.
+*/
 bool
 CleavageAgent::initialize(const CleavageAgent &other)
 {
@@ -749,6 +755,11 @@ CleavageAgent::getCleavageRuleCstSPtrByName(const QString &name) const
   return *(the_iterator_cst);
 }
 
+/*!
+\brief Returns the index of the CleavageRule instance named \a name in the
+member container of CleavageRule intances. If no CleavageRule by name \a name is
+found, -1 is returned.
+*/
 int
 CleavageAgent::getCleavageRuleIndexByName(const QString &name) const
 {
