@@ -45,7 +45,7 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::Cleaver
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup PolChemDefAqueousChemicalReactions
 \inheaderfile Cleaver.hpp
 
@@ -155,8 +155,8 @@ Cleaver::Cleaver(PolymerCstQSPtr polymer_cqsp,
 
   m_calcOptions.initialize(calc_options);
 
-  qDebug() << "Other calc options:" << calc_options.toString();
-  qDebug() << "And now *this calc options:" << m_calcOptions.toString();
+  // qDebug() << "Other calc options:" << calc_options.toString();
+  // qDebug() << "And now *this calc options:" << m_calcOptions.toString();
 
   //  qDebug() << "Instantiating Cleave with Ionizer:" << m_ionizer.toString();
   // qDebug() << "Ionizer' isotopic data:"
@@ -182,8 +182,8 @@ Cleaver::Cleaver(const Cleaver &other)
 
   m_calcOptions.initialize(other.m_calcOptions);
 
-  qDebug() << "Other calc options:" << other.m_calcOptions.toString();
-  qDebug() << "And now *this calc options:" << m_calcOptions.toString();
+  // qDebug() << "Other calc options:" << other.m_calcOptions.toString();
+  // qDebug() << "And now *this calc options:" << m_calcOptions.toString();
 
   //  qDebug() << "Instantiating Cleave with Ionizer:" << m_ionizer.toString();
 }
@@ -322,7 +322,7 @@ Cleaver::cleave(bool reset)
 
   for(int iter = 0; iter <= m_cleavageConfig.getPartials(); ++iter)
     {
-      qDebug() << "Now performing partial cleavage" << iter;
+      // qDebug() << "Now performing partial cleavage" << iter;
 
       if(cleavePartial(iter) == -1)
         {
@@ -370,8 +370,8 @@ Cleaver::fillCleavageIndices()
   IndexRangeCollection index_range_collection(
     m_calcOptions.getIndexRangeCollectionCstRef());
 
-  qDebug() << "The index range collection:"
-           << index_range_collection.indicesAsText();
+  // qDebug() << "The index range collection:"
+  //          << index_range_collection.indicesAsText();
 
   std::size_t index_start;
   std::size_t index_stop;
@@ -387,7 +387,7 @@ Cleaver::fillCleavageIndices()
       index_stop  = index_range_collection.getRangeCstRefAt(0).m_stop;
     }
 
-  qDebug() << "index_start:" << index_start << "index_stop:" << index_stop;
+  // qDebug() << "index_start:" << index_start << "index_stop:" << index_stop;
 
   for(const CleavageMotifSPtr &cleavage_motif_sp : cleavage_motifs)
     {
@@ -535,7 +535,7 @@ Cleaver::findCleavageMotif(CleavageMotif &cleavage_motif,
                            std::size_t index_start,
                            std::size_t index_stop)
 {
-  qDebug() << "start:" << index_start << "stop:" << index_stop;
+  // qDebug() << "start:" << index_start << "stop:" << index_stop;
 
   bool search_failed = false;
 
@@ -653,9 +653,9 @@ Cleaver::findCleavageMotif(CleavageMotif &cleavage_motif,
   // End of
   // while (iter_index < polymer_sequence_monomers.size())
 
-  qDebug() << "At call with start:" << index_start << "stop:" << index_stop
-           << "now returning -1, with cleavage motif"
-           << cleavage_motif.getMotif();
+  // qDebug() << "At call with start:" << index_start << "stop:" << index_stop
+  //          << "now returning -1, with cleavage motif"
+  //          << cleavage_motif.getMotif();
 
   return -1;
 }
@@ -757,6 +757,9 @@ Cleaver::accountCleavageRule(CleavageRuleSPtr cleavage_rule_sp,
           // is not empty.
           Formula rule_formula = Formula(cleavage_rule_sp->getRightFormula());
 
+          // qDebug() << "Right code formula:"
+          //          << rule_formula.getActionFormula();
+
           if(rule_formula.getActionFormula().isEmpty())
             qFatalStream()
               << "Programming error. The cleavage rule's right code is "
@@ -768,8 +771,8 @@ Cleaver::accountCleavageRule(CleavageRuleSPtr cleavage_rule_sp,
 
           if(monomer_csp->getCode() == cleavage_rule_sp->getRightCode())
             {
-              // qDebug() << "Matched right code:" <<
-              // cleavage_rule_sp->getRightCode();
+              // qDebug() << "Matched right code:"
+              //          << cleavage_rule_sp->getRightCode();
 
               // See above for the left end code for detailed explanations.
 
@@ -779,6 +782,10 @@ Cleaver::accountCleavageRule(CleavageRuleSPtr cleavage_rule_sp,
                   // of the whole polymer sequence, so the match is real.
                   // Account for the formula !
 
+                  // qDebug()
+                  //   << "Before accouting rule formula, mono mass:"
+                  //   << oligomer_sp->getMass(Enums::MassType::MONO);
+
                   bool ok = false;
                   rule_formula.accountMasses(
                     ok,
@@ -787,8 +794,18 @@ Cleaver::accountCleavageRule(CleavageRuleSPtr cleavage_rule_sp,
                     oligomer_sp->getMassRef(Enums::MassType::AVG));
 
                   if(!ok)
-                    return false;
+                    {
+                      qDebug() << "Accounting masses set ok to false.";
+                      return false;
+                    }
 
+                  // qDebug()
+                  //   << "After accouting rule formula, mono mass:"
+                  //   << oligomer_sp->getMass(Enums::MassType::MONO);
+
+                  // This will modify the formula inside oligomer_sp.
+                  // However, calling elementalComposition will not account
+                  // for the cleavage rule !
                   oligomer_sp->getFormulaRef().accountFormula(
                     rule_formula.getActionFormula(), isotopic_data_csp, 1, ok);
                 }
@@ -828,8 +845,8 @@ Cleaver::cleavePartial(int partial_cleavage)
     m_calcOptions.getIndexRangeCollectionCstRef()
       .mostInclusiveLeftRightIndexRange();
 
-  qDebug() << "Most inclusive left right index range:"
-           << index_range_p->indicesAsText();
+  // qDebug() << "Most inclusive left right index range:"
+  //          << index_range_p->indicesAsText();
 
   qsizetype index_start = index_range_p->m_start;
   qsizetype index_stop  = index_range_p->m_stop;
@@ -879,8 +896,6 @@ Cleaver::cleavePartial(int partial_cleavage)
 
       right_index = m_doCleaveIndices.at(offset_partial_cleavage);
 
-      qDebug() << "left_index:" << left_index << "right_index:" << right_index;
-
       QString name = QString("%1#%2").arg(partial_cleavage).arg(iter + 1);
 
       // Note how we pass Ionizer() below so that it is invalid
@@ -889,11 +904,11 @@ Cleaver::cleavePartial(int partial_cleavage)
 
       calc_options.setIndexRange(left_index, right_index);
 
-      qDebug() << "After setting these values to calc_options:"
-               << calc_options.getIndexRangeCollectionCstRef()
-                    .getRangesCstRef()
-                    .front()
-                    ->indicesAsText();
+      // qDebug() << "After setting these values to calc_options:"
+      //          << calc_options.getIndexRangeCollectionCstRef()
+      //               .getRangesCstRef()
+      //               .front()
+      //               ->indicesAsText();
 
       OligomerSPtr oligomer_sp = std::make_shared<Oligomer>(
         mcsp_polymer,
@@ -904,12 +919,21 @@ Cleaver::cleavePartial(int partial_cleavage)
         Ionizer(),
         calc_options);
 
+      // qDebug() << "Allocated new oligomer with index range:"
+      //          << left_index << "--" << right_index << "calculation options:"
+      //          << oligomer_sp->getCalcOptionsCstRef().toString()
+      //          << "and default ionizer:"
+      //          << oligomer_sp->getIonizerCstRef().toString();
+
       oligomer_sp->setPartialCleavage(partial_cleavage);
 
       QString elemental_composition = oligomer_sp->elementalComposition();
 
-      qDebug() << "Got elemental composition for that oligomer:"
-               << elemental_composition;
+      // qDebug() << "The elemental composition of this new oligomer as "
+      //             "calculated with its own calculation options:"
+      //          << calc_options.toString() << "and with its own ionizer:"
+      //          << oligomer_sp->getIonizerCstRef().toString()
+      //          << "is:" << elemental_composition;
 
       // And now use that elemental composition to set it in the Oligomer.
 
@@ -926,8 +950,9 @@ Cleaver::cleavePartial(int partial_cleavage)
           return -1;
         }
 
-      // qDebug() << "Oligomer has formula:"
-      //          << oligomer_sp->elementalComposition();
+      // qDebug() << "The elemental composition above was used to set "
+      //             "the oligomer's internal formula, which is now:"
+      //          << oligomer_sp->getFormulaRef().getActionFormula();
 
       // At this point we can add the configured oligomer to the list.
       partial_oligomers.getOligomersRef().push_back(oligomer_sp);
@@ -967,9 +992,9 @@ Cleaver::cleavePartial(int partial_cleavage)
 
   calc_options.setIndexRange(left_index, right_index);
 
-  qDebug() << "Now creating the last cooking cleavage Oligomer:" << name
-           << "with indices:" << left_index << "-" << right_index
-           << "and calculation options:" << calc_options.toString();
+  // qDebug() << "Now creating the last cooking cleavage Oligomer:"
+  //          << name << "with indices:" << left_index << "-" << right_index
+  //          << "and calculation options:" << calc_options.toString();
 
   OligomerSPtr oligomer_sp =
     std::make_shared<Oligomer>(mcsp_polymer,
@@ -982,12 +1007,13 @@ Cleaver::cleavePartial(int partial_cleavage)
 
   oligomer_sp->setPartialCleavage(partial_cleavage);
 
-  qDebug() << "After heap-allocation of Oligomer, its calculation options:"
-           << oligomer_sp->getCalcOptionsRef().toString();
+  // qDebug()
+  //   << "After heap-allocation of Oligomer, its calculation options:"
+  //   << oligomer_sp->getCalcOptionsRef().toString();
 
   QString elemental_composition = oligomer_sp->elementalComposition();
 
-  qDebug() << "Alert Alert elemental composition:" << elemental_composition;
+  // qDebug() << "Elemental composition:" << elemental_composition;
 
   // And now use that elemental composition to set it in the Oligomer.
 
@@ -1003,8 +1029,8 @@ Cleaver::cleavePartial(int partial_cleavage)
       return -1;
     }
 
-  qDebug() << "Alert Alert oligomer has formula:"
-           << oligomer_sp->getFormulaCstRef().getActionFormula();
+  // qDebug() << "Oligomer has formula:"
+  //          << oligomer_sp->getFormulaCstRef().getActionFormula();
 
   // At this point we can add the configured oligomer to the list.
   partial_oligomers.getOligomersRef().push_back(oligomer_sp);
@@ -1080,26 +1106,27 @@ Cleaver::cleavePartial(int partial_cleavage)
       for(const CleavageRuleSPtr &cleavage_rule_sp :
           m_cleavageConfig.getRulesCstRef())
         {
-          // qDebug() << "The CleavageRule name:" << cleavage_rule_sp->getName()
-          //     << "Oligomer mono mass before accounting it:"
-          //     << iter_oligomer_sp->getMass(Enums::MassType::MONO);
+          // qDebug() << "The CleavageRule name:"
+          //          << cleavage_rule_sp->getName()
+          //          << "Oligomer mono mass BEFORE accounting it:"
+          //          << iter_oligomer_sp->getMass(Enums::MassType::MONO)
+          //          << "and internal formula is:"
+          //          << iter_oligomer_sp->getFormulaCstRef().getActionFormula();
 
           // Note that the accounting of the cleavage rule is
           // performed as if the oligomer was charged 1. This is why
           // we have to ionize the oligomer only after we have
           // completed the determination of its atomic composition.
 
-          // qDebug() << "Accounting for cleavagerule:"
-          //   << cleavage_rule_name_sp_pair.second->getName();
-
-          // qDebug() << "Oligomer mono mass before:"
-          //   << iter_oligomer_sp->getMass(Enums::MassType::MONO);
-
           if(!accountCleavageRule(cleavage_rule_sp, iter_oligomer_sp))
             return -1;
 
-          // qDebug() << "Oligomer mono mass after:"
-          //     << iter_oligomer_sp->getMass(Enums::MassType::MONO);
+          // qDebug() << "The CleavageRule name:"
+          //          << cleavage_rule_sp->getName()
+          //          << "Oligomer mono mass AFTER accounting it:"
+          //          << iter_oligomer_sp->getMass(Enums::MassType::MONO)
+          //          << "and internal formula has become:"
+          //          << iter_oligomer_sp->getFormulaCstRef().getActionFormula();
         }
 
       // qDebug() << "Done iterating in the CleavageRule instances.";
@@ -1113,7 +1140,7 @@ Cleaver::cleavePartial(int partial_cleavage)
       int ionization_level      = m_cleavageConfig.getStartIonizeLevel();
       int ionization_stop_level = m_cleavageConfig.getStopIonizeLevel();
 
-      //      qDebug() << "The Ionizer:" << m_ionizer.toString();
+      qDebug() << "The Ionizer:" << m_ionizer.toString();
 
       // Sanity checks
       if(!m_ionizer.isValid())
@@ -1122,6 +1149,12 @@ Cleaver::cleavePartial(int partial_cleavage)
         qFatalStream()
           << "Programming error. The Ionizer cannot have ionized status.";
 
+      // qDebug() << "BEFORE ionization:"
+      //          << "Oligomer mono mass:"
+      //          << iter_oligomer_sp->getMass(Enums::MassType::MONO)
+      //          << "and internal formula is:"
+      //          << iter_oligomer_sp->getFormulaCstRef().getActionFormula();
+
       while(ionization_level <= ionization_stop_level)
         {
           Ionizer temp_ionizer(m_ionizer);
@@ -1159,11 +1192,11 @@ Cleaver::cleavePartial(int partial_cleavage)
               return -1;
             }
 
-          // qDebug() << "After ionization level" << ionization_level
-          //   << "with formula:"
-          //   << temp_ionizer.getFormulaCstRef().getActionFormula()
-          //   << ", the new oligomer formula is:"
-          //   << new_oligomer_sp->getFormulaCstRef().getActionFormula();
+          // qDebug() << "AFTER ionization level:" << ionization_level
+          //          << "Oligomer mono mass:"
+          //          << iter_oligomer_sp->getMass(Enums::MassType::MONO)
+          //          << "and internal formula has become:"
+          //          << iter_oligomer_sp->getFormulaCstRef().getActionFormula();
 
           // The name was set already during the creation of the
           // template oligomer. All we have to add to the name is the
@@ -1491,14 +1524,14 @@ Cleaver::analyzeCrossLinkedOligomer(OligomerSPtr oligomer_sp,
   if(!ok)
     return -1;
 
-  qDebug() << "Oligomer start:" << index_start << "stop:" << index_stop;
+  // qDebug() << "Oligomer start:" << index_start << "stop:" << index_stop;
 
   const std::vector<CrossLinkSPtr> &polymer_cross_links =
     mcsp_polymer->getCrossLinksCstRef();
 
   for(std::size_t iter = index_start; iter < index_stop + 1; ++iter)
     {
-      qDebug() << "iter:" << iter;
+      // qDebug() << "iter:" << iter;
 
       MonomerSPtr monomer_csp =
         mcsp_polymer->getSequenceCstRef().getMonomerCstSPtrAt(iter);
@@ -1757,6 +1790,10 @@ Cleaver::analyzeCrossLinkedOligomer(OligomerSPtr oligomer_sp,
 }
 
 //////////////// OPERATORS /////////////////////
+
+/*!
+\brief Returns a reference to this Cleaver instance after initialization using \a other.
+*/
 Cleaver &
 Cleaver::operator=(const Cleaver &other)
 {
