@@ -266,6 +266,10 @@ CrossLink::getPolymerCstSPtr() const
 }
 
 //////////////// THE CROSS-LINKER /////////////////////
+
+/*!
+\brief Returns the member CrossLinker.
+*/
 const CrossLinkerCstSPtr
 CrossLink::getCrossLinkerCstSPtr() const
 {
@@ -350,7 +354,7 @@ CrossLink::getMonomerAt(std::size_t index)
 }
 
 /*!
-\brief Removes the Monomer at \a index in the member list of \l Monomer
+\brief Removes the Monomer at \a index in the member container of \l Monomer
 instances.
 
 \a index cannot be out of bounds.
@@ -371,6 +375,61 @@ CrossLink::removeMonomerAt(std::size_t index)
   return removeMonomer(monomer_csp);
 }
 
+/*!
+\brief Removes Monomer \a monomer_csp from the member container of Monomer
+ intances.
+
+ Returns true if a Monomer was indeed removed, false otherwise.
+ */
+bool
+CrossLink::removeMonomer(MonomerCstSPtr monomer_csp)
+{
+  if(monomer_csp == nullptr || monomer_csp.get() == nullptr)
+    qFatalStream() << "Cannot be that pointer is nullptr.";
+
+  // We will need this anyway.
+  QString uuid = getUuidForMonomer(monomer_csp);
+
+  std::vector<MonomerCstSPtr>::const_iterator the_iterator_cst =
+    std::find_if(m_monomers.begin(),
+                 m_monomers.end(),
+                 [monomer_csp](MonomerCstSPtr iter_modif_sp) {
+                   return iter_modif_sp == monomer_csp;
+                 });
+
+  if(the_iterator_cst == m_monomers.end())
+    {
+      qCritical() << "The MonomerCstSPtr was not found in the container.";
+
+      if(!uuid.isEmpty())
+        qFatalStream()
+          << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
+
+      return false;
+    }
+
+  // At this point, both containers contain modif_sp.
+
+  m_monomers.erase(the_iterator_cst);
+
+  std::vector<UuidMonomerCstWPtrPair>::const_iterator the_pair_iterator_cst =
+    std::find_if(m_uuidMonomerPairs.cbegin(),
+                 m_uuidMonomerPairs.cend(),
+                 [uuid](const UuidMonomerCstWPtrPair &the_pair) {
+                   // Do not query the modif_sp managed object because it can
+                   // be nullptr!
+                   return the_pair.first == uuid;
+                 });
+
+  if(the_pair_iterator_cst == m_uuidMonomerPairs.cend())
+    qFatalStream()
+      << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
+
+  m_uuidMonomerPairs.erase(the_pair_iterator_cst);
+
+  return true;
+}
+
 /*!
 \brief Sets in the Monomer container, the Monomer instances occurring at the
 indices listed in \a monomer_indices_text.
@@ -522,7 +581,7 @@ For example, if the cross-link involves Monomer instances at indices 20, 45, 89,
 then the indices are this range of indices: [20--89].
 */
 std::vector<std::size_t>
-CrossLink::locationssOfOnlyExtremeSequenceMonomers(
+CrossLink::locationsOfOnlyExtremeSequenceMonomers(
   Enums::LocationType location_type) const
 {
   std::vector<std::size_t> continuum_locations =
@@ -554,7 +613,7 @@ CrossLink::locationsOfOnlyExtremeSequenceMonomersAsText(
   Enums::LocationType location_type) const
 {
   std::vector<std::size_t> locations =
-    locationssOfOnlyExtremeSequenceMonomers(location_type);
+    locationsOfOnlyExtremeSequenceMonomers(location_type);
 
   return formatContainerOfMonomerLocationsAsText(locations);
 }
@@ -1160,10 +1219,9 @@ which is why it has the neutral "locations" term in its name.
 
 If the container is empty, an empty string is returned.
 
-\sa continuumOfLocationsOfInclusiveSequenceMonomers(
-  Enums::LocationType location_type),
-indicesOfOnlyExtremeSequenceMonomers(),
-indicesOfOnlyExtremeSequenceMonomersAsText()
+\sa continuumOfLocationsOfInclusiveSequenceMonomers(),
+locationsOfOnlyExtremeSequenceMonomers(),
+locationsOfOnlyExtremeSequenceMonomersAsText()
 */
 QString
 CrossLink::formatContainerOfMonomerLocationsAsText(
@@ -1364,6 +1422,9 @@ CrossLink::getAllMonomerUuids() const
   return the_uuid_strings;
 }
 
+/*!
+\brief Returns a text string describing this CrossLink instance.
+*/
 QString
 CrossLink::toString() const
 {
@@ -1391,55 +1452,6 @@ CrossLink::toString() const
   return text;
 }
 
-bool
-CrossLink::removeMonomer(MonomerCstSPtr monomer_csp)
-{
-  if(monomer_csp == nullptr || monomer_csp.get() == nullptr)
-    qFatalStream() << "Cannot be that pointer is nullptr.";
-
-  // We will need this anyway.
-  QString uuid = getUuidForMonomer(monomer_csp);
-
-  std::vector<MonomerCstSPtr>::const_iterator the_iterator_cst =
-    std::find_if(m_monomers.begin(),
-                 m_monomers.end(),
-                 [monomer_csp](MonomerCstSPtr iter_modif_sp) {
-                   return iter_modif_sp == monomer_csp;
-                 });
-
-  if(the_iterator_cst == m_monomers.end())
-    {
-      qCritical() << "The MonomerCstSPtr was not found in the container.";
-
-      if(!uuid.isEmpty())
-        qFatalStream()
-          << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
-
-      return false;
-    }
-
-  // At this point, both containers contain modif_sp.
-
-  m_monomers.erase(the_iterator_cst);
-
-  std::vector<UuidMonomerCstWPtrPair>::const_iterator the_pair_iterator_cst =
-    std::find_if(m_uuidMonomerPairs.cbegin(),
-                 m_uuidMonomerPairs.cend(),
-                 [uuid](const UuidMonomerCstWPtrPair &the_pair) {
-                   // Do not query the modif_sp managed object because it can
-                   // be nullptr!
-                   return the_pair.first == uuid;
-                 });
-
-  if(the_pair_iterator_cst == m_uuidMonomerPairs.cend())
-    qFatalStream()
-      << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
-
-  m_uuidMonomerPairs.erase(the_pair_iterator_cst);
-
-  return true;
-}
-
 /*!
 \brief Removes from the member container all the Monomer instance pointers that
 are not found to still be alive.
