@@ -229,7 +229,13 @@ CrossLinker::~CrossLinker()
   // We do not own the modifications in m_modifList!
 }
 
+/*!
+\brief Initializes this CrossLinker instance using \a element, according to  \a version.
 
+Returns true if the rendering of \a element was successful, false otherwise.
+
+\sa renderXmlClkElement()
+*/
 bool
 CrossLinker::initialize(const QDomElement &element, int version)
 {
@@ -273,6 +279,10 @@ CrossLinker::getPolChemDefCstSPtr() const
 }
 
 //////////////// THE NAME /////////////////////
+
+/*!
+\brief Sets the \a name of the CrossLinker.
+*/
 void
 CrossLinker::setName(const QString &name)
 {
