@@ -299,6 +299,9 @@ Formula::~Formula()
 {
 }
 
+/*!
+\brief Return a newly allocated Formula that is initialized using \a other and setting its parent to \a parent.
+*/
 Formula *
 Formula::clone(const Formula &other, QObject *parent)
 {
@@ -307,6 +310,9 @@ Formula::clone(const Formula &other, QObject *parent)
   return copy_p;
 }
 
+/*!
+\brief Return a reference to this Formula after having initialized it using \a other.
+*/
 Formula &
 Formula::initialize(const Formula &other)
 {
@@ -1524,7 +1530,6 @@ Formula::symbolCount(const QString &symbol) const
   return iter->second;
 }
 
-//! Account the atoms in \c this \c m_actionFormula.
 /*!
 \brief Accounts this Formula's action-formula (m_actionFormula) in the symbol /
 count member container (m_symbolCountMap).
@@ -1543,8 +1548,7 @@ formulas onto formulas sequentially.
 
 Returns true if no error was encountered, false otherwise.
 
-\sa splitActionParts(), MsXpS::libXpertMassCore::Polymer::elementalComposition(const CalcOptions
-&calc_options, const Ionizer &ionizer)
+\sa splitActionParts(), Polymer::elementalComposition
 */
 bool
 Formula::accountSymbolCounts(IsotopicDataCstSPtr isotopic_data_csp, int times)
@@ -1683,8 +1687,8 @@ Formula::accountFormula(const QString &formula_string,
                         double times,
                         bool &ok)
 {
-  // qDebug() << "Accounting in this formula:" << m_actionFormula
-  //          << "the external formula:" << formula_string;
+  qDebug() << "Accounting in this formula:" << m_actionFormula
+           << "the external formula:" << formula_string;
 
   // qDebug() << "Before having merged the external formula's map into this one,
   // " "this one has size:"
@@ -2131,6 +2135,7 @@ Formula::accountMasses(bool &ok,
        isotopic_data_csp, times, true /* store */, true /* reset */) ==
      SplitResult::FAILURE)
     {
+      qDebug() << "The formula splitting into actions failed.";
       m_isValid = false;
       ok        = false;
       return *this;
