@@ -136,6 +136,10 @@ IndexRangeCollection::~IndexRangeCollection()
 {
 }
 
+/*!
+\brief Initializes this IndexRangeCollection instance using \a other and returns
+a reference to this instance.
+*/
 IndexRangeCollection &
 IndexRangeCollection::initialize(const IndexRangeCollection &other)
 {
@@ -150,6 +154,10 @@ IndexRangeCollection::initialize(const IndexRangeCollection &other)
   return *this;
 }
 
+/*!
+ \brief Returns a newly allocated IndexRangeCollection instance with parent set
+ to \a parent.
+ */
 IndexRangeCollection *
 IndexRangeCollection::clone(QObject *parent)
 {
@@ -161,6 +169,10 @@ IndexRangeCollection::clone(QObject *parent)
   return copy_p;
 }
 
+/*!
+ \ b*rief Returns a newly allocated IndexRangeCollection instance initialized
+ using \a other and with parent set to \a parent.
+ */
 IndexRangeCollection *
 IndexRangeCollection::clone(const IndexRangeCollection &other, QObject *parent)
 {
