@@ -47,12 +47,12 @@
 #include "MsXpS/libXpertMassCore/Utils.hpp"
 
 
-
 int isotopeMetaTypeId = qRegisterMetaType<MsXpS::libXpertMassCore::Isotope>(
   "MsXpS::libXpertMassCore::Isotope");
 
-int isotopePtrMetaTypeId = qRegisterMetaType<MsXpS::libXpertMassCore::Isotope *>(
-  "MsXpS::libXpertMassCore::IsotopePtr");
+int isotopePtrMetaTypeId =
+  qRegisterMetaType<MsXpS::libXpertMassCore::Isotope *>(
+    "MsXpS::libXpertMassCore::IsotopePtr");
 
 int isotopeSPtrMetaTypeId =
   qRegisterMetaType<QSharedPointer<MsXpS::libXpertMassCore::Isotope>>(
@@ -62,7 +62,6 @@ int isotopeCstSPtrMetaTypeId =
   qRegisterMetaType<QSharedPointer<MsXpS::libXpertMassCore::Isotope>>(
     "QSharedPointer<const MsXpS::libXpertMassCore::Isotope>");
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -105,7 +104,7 @@ the proper order in the overloaded initialize() function.
 
 /*!
 \class MsXpS::libXpertMassCore::Isotope
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup PolChemDefBuildingdBlocks
 \inheaderfile Isotope.hpp
 
@@ -134,6 +133,7 @@ Please, see \l{https://github.com/MatteoLacki/IsoSpec/}.
 
 Cannot be negative.
 */
+
 /*!
 \variable MsXpS::libXpertMassCore::Isotope::m_probability
 \brief The probability of this isotope, that is, its abundance.
@@ -141,6 +141,13 @@ Cannot be negative.
 Cannot be negative nor superior to 1.
 */
 
+/*!
+ \variable MsXpS::libXpertMassCore::Isotope::m_isValid
+ \brief The validity status of this isotope.
+
+\sa validate()
+ */
+
 /*!
 \typedef MsXpS::libXpertMassCore::IsotopeQSPtr
 \relates Isotope
@@ -161,25 +168,30 @@ Synonym for std::shared_ptr<const Isotope>.
 The Isotope instance is invalid. It can be later intialized
 with the setter functions or the initialization functions.
 
-\sa initialize()
+\sa initialize(const QString &), initialize(const QString &name,
+const QString &symbol,
+double mass,
+double probability)
 */
 Isotope::Isotope(QObject *parent): QObject(parent)
 {
 }
 
 /*!
-\brief Constructs the \l{Isotope} with all the required arguments.
+ \overload
+ \brief Constructs the \l{Isotope} with all the required arguments.
 
 The isotope is created as a fully documented instance if all the following
-parameters a correctly set:
+parameters are correctly set:
 
-\a name \l{MsXpS::libXpertMassCore::Isotope::m_name} (element name)
+\list
+\li \a name (\l{m_name}): element's name
+\li \a symbol (\l{m_symbol}): element's symbol
+\li \a mass (\l{m_mass}): isotope's mass
+\li \a probability (\l{m_probability}): isotope's probability, that is abundance
+\endlist
 
-\a symbol \l{MsXpS::libXpertMassCore::Isotope::m_symbol} (element symbol)
-
-\a mass \l{MsXpS::libXpertMassCore::Isotope::m_mass} (isotope mass)
-
-\a probability \l{MsXpS::libXpertMassCore::Isotope::m_probability} (isotope
+\sa initialize(const QString &name, const QString &symbol, double mass, double
 probability)
 */
 Isotope::Isotope(const QString &name,
@@ -207,7 +219,9 @@ Isotope::Isotope(const QString &name,
 }
 
 /*!
-\brief Constructs the \l{Isotope} as a copy of \a other.
+ \overload
+ \brief Constructs the \l{Isotope} as a copy of \a other setting parent to \a
+parent.
 */
 Isotope::Isotope(const Isotope &other, QObject *parent): QObject(parent)
 {
@@ -232,7 +246,9 @@ Isotope::Isotope(const Isotope &other, QObject *parent): QObject(parent)
 }
 
 /*!
-\brief Constructs the \l{Isotope} as a copy of \a other.
+ \overload
+ \brief Constructs the \l{Isotope} as a copy of \a other_p, setting parent to \a
+parent.
 */
 Isotope::Isotope(const Isotope *other_p, QObject *parent): QObject(parent)
 {
@@ -258,12 +274,19 @@ Isotope::Isotope(const Isotope *other_p, QObject *parent): QObject(parent)
 }
 
 /*!
-\brief Constructs the \l{Isotope} using all the data in the \a text string.
+ \overload
+\brief Isotope::Isotope(const QString &text, QObject *parent)
 
-The strings contains all the Isotope data, separated by a comma ',' exactly
+Constructs this \l{Isotope} using all the data in the \a text string,
+setting parent to \a parent.
+
+The string contains all the Isotope data, separated by a comma ',' exactly
 with the same format as that implemented by Isotope::toString().
 
-\sa initialize(const QString &text), toString()
+\sa initialize(const QString &), initialize(const QString &name,
+const QString &symbol,
+double mass,
+double probability), toString()
 */
 Isotope::Isotope(const QString &text, QObject *parent): QObject(parent)
 {
@@ -274,7 +297,7 @@ Isotope::Isotope(const QString &text, QObject *parent): QObject(parent)
 }
 
 /*!
-\brief Destructs the \l{Isotope}.
+\brief Destructs this Isotope.
 */
 Isotope::~Isotope()
 {
@@ -409,8 +432,6 @@ Isotope::initialize(const QString &name,
 }
 
 /*!
-\overload MsXpS::libXpertMassCore::initialize(const QString &text)
-
 \brief Initializes the \l{Isotope} using all the data in the \a text string.
 
 The string passed as argument is QString::simplified() and
@@ -422,7 +443,7 @@ values to initalize all the member data.
 Returns true if the string contained valid substrings that successfully
 initialized the \l{Isotope}, false otherwise.
 
-\sa Isotope(const QString &text), initialize(const QString &name,
+\sa Isotope(const QString &text, QObject *parent), initialize(const QString &name,
                     const QString &symbol,
                     double mass,
                     double probability)
@@ -478,8 +499,6 @@ Isotope::initialize(const QString &text)
 }
 
 /*!
-\overload MsXpS::libXpertMassCore::initializeVersion1(const QString &text)
-
 \brief Initializes the \l{Isotope} using all the data in the \a text string.
 
 The string passed as argument is QString::simplified() and
@@ -494,7 +513,7 @@ values to initalize all the member data.
 Returns true if the string contained valid substrings that successfully
 initialized the \l{Isotope}, false otherwise.
 
-\sa Isotope(const QString &text), initialize(const QString &name,
+\sa Isotope(const QString &text, QObject *parent), initialize(const QString &name,
                     const QString &symbol,
                     double mass,
                     double probability)
@@ -606,8 +625,6 @@ Isotope::initializeVersion1(const QString &text)
 }
 
 /*!
-\overload MsXpS::libXpertMassCore::initializeVersion2(const QString &text)
-
 \brief Initializes the \l{Isotope} using all the data in the \a text string.
 
 The string passed as argument is QString::simplified() and
@@ -619,10 +636,8 @@ text at ',' delimiter defines what data element it corresponds to.
 Returns true if the string contained valid substrings that successfully
 initialized the \l{Isotope}, false otherwise.
 
-\sa Isotope(const QString &text), initialize(const QString &name,
-                    const QString &symbol,
-                    double mass,
-                    double probability)
+\sa Isotope(const QString &text, QObject *parent), initialize(const QString &name, const QString
+&symbol, double mass, double probability)
 */
 bool
 Isotope::initializeVersion2(const QString &text)
@@ -857,14 +872,22 @@ Isotope::getProbability() const
 \brief Validates the isotope.
 
 The element name, symbol, mass and probability member data are scrutinized and
-if errors are detected descriptive error messages are added to \a error_list.
+if errors are detected descriptive error messages are added to \a error_list_p.
 
 For example, for symbol:
 
 \code
 if(m_symbol.isEmpty())
 {
-error_list_p->push_back(The symbol is not set.";
+local_text = m_symbol.simplified();
+regexp.setPattern("^[A-Z][a-z]*$");
+
+if(!regexp.match(local_text).hasMatch())
+{
+error_msg = "Failed to validate the element's symbol.";
+error_list_p->push_back(error_msg);
+qWarning() << error_msg;
+}
 }
 \endcode
 
@@ -929,6 +952,9 @@ Isotope::validate(ErrorList *error_list_p)
   return m_isValid;
 }
 
+/*!
+\brief Return the member datum \l{m_isValid}.
+*/
 bool
 Isotope::isValid() const
 {
@@ -986,8 +1012,6 @@ return QString("%1,%2,%3,%4")
 .arg(m_mass, 0, 'f', 60)
 .arg(m_probability, 0, 'f', 60);
 \endcode
-
-Returns a string.
 */
 QString
 Isotope::toString() const
