@@ -78,8 +78,8 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::IsotopicClusterGenerator
-\inmodule libXpertMass
-\ingroup XpertMassMassCalculations
+\inmodule libXpertMassCore
+\ingroup XpertMassCoreMassCalculations
 \inheaderfile IsotopicClusterGenerator.hpp
 
 \brief The IsotopicClusterGenerator class provides the features needed to model
@@ -109,6 +109,33 @@ abundances.
 \value MANUAL_CONFIG: The isotopic data are in a specific format, different
 than the two above, that actually crafts the isotopes starting from scratch.
 */
+
+/*!
+ \typealias MsXpS::libXpertMassCore::FormulaChargePair
+
+ Alias for std::pair<QString, int>.
+ */
+
+/*!
+ \typealias MsXpS::libXpertMassCore::IsotopicClusterChargePair
+
+ Alias for std::pair<pappso::TraceCstSPtr, int>.
+ */
+
+/*!
+ \typedef MsXpS::libXpertMassCore::IsotopicClusterGeneratorSPtr
+ \relates IsotopicClusterGenerator.
+
+ Synonym for std::shared_ptr<IsotopicClusterGenerator>.
+ */
+
+/*!
+ \typedef MsXpS::libXpertMassCore::IsotopicClusterGeneratorCstSPtr
+ \relates IsotopicClusterGenerator.
+
+ Synonym for std::shared_ptr<const IsotopicClusterGenerator>.
+ */
+
 /*!
 \variable MsXpS::libXpertMassCore::IsotopicClusterGenerator::msp_isotopicData
 
@@ -160,33 +187,6 @@ the other cluster peaks.
 */
 
 
-/*!
-\typealias MsXpS::libXpertMassCore::FormulaChargePair
-
-Alias for std::pair<QString, int>.
-*/
-
-/*!
-\typealias MsXpS::libXpertMassCore::IsotopicClusterChargePair
-
-Alias for std::pair<pappso::TraceCstSPtr, int>.
-*/
-
-/*!
-\typedef MsXpS::libXpertMassCore::IsotopicClusterGeneratorSPtr
-\relates IsotopicClusterGenerator.
-
-Synonym for std::shared_ptr<IsotopicClusterGenerator>.
-*/
-
-/*!
-\typedef MsXpS::libXpertMassCore::IsotopicClusterGeneratorCstSPtr
-\relates IsotopicClusterGenerator.
-
-Synonym for std::shared_ptr<const IsotopicClusterGenerator>.
-*/
-
-
 
 /*!
 \brief Constructs a IsotopicClusterGenerator instance.
