@@ -51,11 +51,11 @@
 
 /////////////////////// Local includes
 #include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/Utils.hpp"
 #include "MsXpS/libXpertMassCore/MassDataCborMassSpectrumHandler.hpp"
 #include "MsXpS/libXpertMassCore/IsotopicClusterShaper.hpp"
 #include "MsXpS/libXpertMassCore/MassPeakShaper.hpp"
 
-
 namespace MsXpS
 {
 
@@ -65,8 +65,8 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::IsotopicClusterShaper
-\inmodule libXpertMass
-\ingroup XpertMassMassCalculations
+\inmodule libXpertMassCore
+\ingroup XpertMassCoreMassCalculations
 \inheaderfile IsotopicClusterShaper.hpp
 
 \brief The IsotopicClusterShaper class provides the features needed to shape
@@ -90,13 +90,14 @@ points in the different traces.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::IsotopicClusterShaper::m_isotopicClusterChargePairs
+\variable
+MsXpS::libXpertMassCore::IsotopicClusterShaper::m_isotopicClusterChargePairs
 
 \brief Vector of pappso::Trace instances in pair with charges.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::IsotopicClusterShaper::m_config
+\variable MsXpS::libXpertMassCore::IsotopicClusterShaper::mp_massPeakShaperConfig
 
 \brief The configuration driving the mass peak shaping process.
 */
@@ -170,13 +171,12 @@ IsotopicClusterShaper::IsotopicClusterShaper(
   const pappso::Trace &isotopic_cluster,
   int charge,
   const MassPeakShaperConfig &config)
-  : m_config(config)
+  : mp_massPeakShaperConfig(new MassPeakShaperConfig(config))
 {
   // No need to reset, we are constructing.
   setIsotopicCluster(isotopic_cluster, charge, false);
 }
 
-
 /*!
 \brief Constructs a IsotopicClusterShaper instance.
 
@@ -194,7 +194,7 @@ different charges.
 IsotopicClusterShaper::IsotopicClusterShaper(
   const std::vector<IsotopicClusterChargePair> &isotopic_cluster_charge_pairs,
   const MassPeakShaperConfig &config)
-  : m_config(config)
+  : mp_massPeakShaperConfig(new MassPeakShaperConfig(config))
 {
   // No need to reset, we are constructing.
   setIsotopicClusterChargePairs(isotopic_cluster_charge_pairs, false);
@@ -211,22 +211,20 @@ IsotopicClusterShaper::~IsotopicClusterShaper()
 \brief Sets the peak shaping process \a{config}uration.
 */
 void
-IsotopicClusterShaper::setConfig(MassPeakShaperConfig config)
+IsotopicClusterShaper::setConfig(const MassPeakShaperConfig &config)
 {
-  m_config.initialize(config);
+  mp_massPeakShaperConfig->initialize(config);
 }
 
-
 /*!
 \brief Gets the peak shaping process configuration.
 */
-MassPeakShaperConfig
+const MassPeakShaperConfig *
 IsotopicClusterShaper::getConfig() const
 {
-  return m_config;
+  return mp_massPeakShaperConfig;
 }
 
-
 /*!
 \brief Sets the intensity normalization value to \a max_intensity.
 */
@@ -236,7 +234,6 @@ IsotopicClusterShaper::setNormalizeIntensity(int max_intensity)
   m_normalizeIntensity = max_intensity;
 }
 
-
 /*!
 \brief Gets the intensity normalization value.
 */
@@ -269,9 +266,12 @@ IsotopicClusterShaper::run(bool reset)
       m_finalTrace.clear();
     }
 
-  if(!m_config.resolve())
+  ErrorList error_list;
+
+  if(!mp_massPeakShaperConfig->resolve(error_list))
     {
-      qDebug() << "The peak shaper configuration failed to resolve.";
+      qDebug() << "Failed to resolve the MassPeakShaperConfig with errors:\n"
+               << Utils::joinErrorList(error_list, "\n");
       return m_finalTrace;
     }
 
@@ -298,7 +298,7 @@ IsotopicClusterShaper::run(bool reset)
 
   // Configure the mass spectrum combiner in case we need binning.
 
-  if(m_config.isWithBins())
+  if(mp_massPeakShaperConfig->isWithBins())
     {
       // Bins were requested.
 
@@ -306,7 +306,7 @@ IsotopicClusterShaper::run(bool reset)
 
       // Get the bin size out of the configuration.
 
-      double bin_size = m_config.getBinSize();
+      double bin_size = mp_massPeakShaperConfig->getBinSize();
 
       // qDebug() << "The bin size in the config is:" << bin_size;
 
@@ -315,7 +315,8 @@ IsotopicClusterShaper::run(bool reset)
       // encountered in all that peak shaping activity. We thus can create the
       // bins faithfully.
 
-      Enums::MassPeakWidthLogic logic = m_config.getMassPeakWidthLogic();
+      Enums::MassPeakWidthLogic logic =
+        mp_massPeakShaperConfig->getMassPeakWidthLogic();
 
       // The m_smallestMz and m_greatestMz values have been determined by
       // looking into the unshaped isotopic clusters passed to this object
@@ -338,24 +339,24 @@ IsotopicClusterShaper::run(bool reset)
             m_greatestMz + 1,
             pappso::MzIntegrationParams::BinningType::ARBITRARY,
             pappso::PrecisionFactory::getDaltonInstance(bin_size),
-            /*binSizeDivisor*/1,
-            /*decimalPlacesr*/-1,
+            /*binSizeDivisor*/ 1,
+            /*decimalPlacesr*/ -1,
             true,
-          nullptr);
+            nullptr);
         }
       else if(logic == Enums::MassPeakWidthLogic::RESOLUTION)
         {
-          double resolution = m_config.getResolution();
+          double resolution = mp_massPeakShaperConfig->getResolution();
 
           m_mzIntegrationParams.initialize(
             m_smallestMz - 1,
             m_greatestMz + 1,
             pappso::MzIntegrationParams::BinningType::ARBITRARY,
             pappso::PrecisionFactory::getResInstance(resolution),
-            m_config.getBinSizeDivisor(),
+            mp_massPeakShaperConfig->getBinSizeDivisor(),
             -1,
             true,
-          nullptr);
+            nullptr);
         }
       else
         qFatal(
@@ -390,14 +391,14 @@ IsotopicClusterShaper::run(bool reset)
           // Note the division by m_charge below!
 
           pappso::Trace trace = MassPeakShaper::computePeakShape(
-            data_point.x / charge, data_point.y, m_config);
+            data_point.x / charge, data_point.y, *mp_massPeakShaperConfig);
 
           // qDebug() << "The shaped isotopic cluster has size:" <<
           // trace.size();
 
           if(trace.size())
             {
-              if(m_config.isWithBins())
+              if(mp_massPeakShaperConfig->isWithBins())
                 mass_spectrum_plus_combiner.combine(m_mapTrace, trace);
               else
                 trace_plus_combiner.combine(m_mapTrace, trace);
@@ -484,10 +485,9 @@ IsotopicClusterShaper::setIsotopicCluster(
   m_isotopicClusterChargePairs.push_back(
     IsotopicClusterChargePair(isotopic_cluster_sp, charge));
 
-  m_config.setReferencePeakMz(m_mostIntensePeakMz);
+  mp_massPeakShaperConfig->setReferencePeakMz(m_mostIntensePeakMz);
 }
 
-
 /*!
 \brief Handles the \a isotopic_cluster_sp input isotopic cluster as a
 pappso::Trace.
@@ -504,7 +504,6 @@ IsotopicClusterShaper::setIsotopicCluster(
   setIsotopicCluster(isotopic_cluster_sp, charge, true);
 }
 
-
 /*!
 \brief Handles the \a isotopic_cluster input isotopic cluster as a
 pappso::Trace.
@@ -522,7 +521,6 @@ IsotopicClusterShaper::setIsotopicCluster(const pappso::Trace &isotopic_cluster,
     std::make_shared<const pappso::Trace>(isotopic_cluster), charge, reset);
 }
 
-
 /*!
 \brief Handles the \a isotopic_cluster input isotopic cluster as a
 pappso::Trace.
@@ -540,7 +538,6 @@ IsotopicClusterShaper::setIsotopicCluster(const pappso::Trace &isotopic_cluster,
     std::make_shared<const pappso::Trace>(isotopic_cluster), charge, true);
 }
 
-
 /*!
 \brief Handles the \a isotopic_cluster_charge_pair input isotopic cluster as a
 IsotopicClusterChargePair.
@@ -557,7 +554,6 @@ IsotopicClusterShaper::setIsotopicCluster(
                      true);
 }
 
-
 /*!
 \brief Handles the \a isotopic_cluster_charge_pair input isotopic cluster as a
 IsotopicClusterChargePair.
@@ -574,7 +570,6 @@ IsotopicClusterShaper::setIsotopicCluster(
                      reset);
 }
 
-
 /*!
 \brief Handles the \a isotopic_cluster_charge_pairs input isotopic cluster as a
 vector of IsotopicClusterChargePair instances.
@@ -596,7 +591,6 @@ IsotopicClusterShaper::setIsotopicClusterChargePairs(
   //<< "m_mostIntensePeakMz:" << m_mostIntensePeakMz;
 }
 
-
 /*!
 \brief Handles the \a isotopic_cluster_charge_pairs input isotopic cluster as a
 vector of IsotopicClusterChargePair instances.
@@ -631,7 +625,6 @@ IsotopicClusterShaper::appendIsotopicCluster(
   setIsotopicCluster(isotopic_cluster, charge, false);
 }
 
-
 /*!
 \brief Adds  isotopic clusters in the form of the \a
 isotopic_cluster_charge_pairs vector of IsotopicClusterChargePair instances.
