@@ -71,7 +71,7 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::IsotopicData
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup PolChemDefBuildingdBlocks
 \inheaderfile IsotopicData.hpp
 
@@ -106,6 +106,14 @@ the IsoSpec library tables or by reading data from a user-configured file.
 \brief The map relating the Isotope::m_symbol to the average mass.
 */
 
+/*!
+\variable MsXpS::libXpertMassCore::IsotopicData::m_isValid
+
+\brief The validity status of the IsotopicData instance.
+
+\sa isValid(), validate()
+*/
+
 
 /*!
 \typedef MsXpS::libXpertMassCore::IsotopicDataSPtr
@@ -445,7 +453,6 @@ this collection.
 std::size_t
 IsotopicData::updateMonoMassMap()
 {
-
   // For all the common chemical elements found in organic substances, the
   // monoisotopic mass is the mass of the most abundant isotope which
   // happens to be also the lightest isotope. However that is not true for
@@ -608,7 +615,7 @@ iter_pair iterator range.
 \a iter_pair pair of [begin -- end[ iterators to the isotopes in this
 collection
 
-\a error_list vector of strings in which to store error messages
+\a error_list_p vector of strings in which to store error messages
 
 There are no sanity checks performed. The iterator pair should hold two
 iterator values that frame isotopes of the same chemical element.
@@ -761,7 +768,7 @@ IsotopicData::getMonoMassBySymbol(const QString &symbol, bool &ok) const
 The range of isotopes is defined by \a iter_pair, that is [ \a iter_pair
 .first -- \a iter_pair .second [.
 
-If errors are encountered, these are appended to \a error_list.
+If errors are encountered, these are appended to \a error_list_p.
 
 For all the common chemical elements found in organic substances, the
 monoisotopic mass is the mass of the most abundant isotope which
@@ -846,7 +853,7 @@ IsotopicData::getAvgMassBySymbol(const QString &symbol, bool &ok) const
 \brief Returns the sum of the probabilities of all the isotopes of \a
 symbol.
 
-If errors occur, they will be described as strings appended in \a error_list.
+If errors occur, they will be described as strings appended in \a error_list_p.
 */
 double
 IsotopicData::getCumulatedProbabilitiesBySymbol(const QString &symbol,
@@ -896,7 +903,7 @@ iter_pair range of iterators.
 The range of isotopes is defined by \a iter_pair, that is [ \a iter_pair
 .first -- \a iter_pair .second [.
 
-If errors are encountered, these are appended to \a error_list.
+If errors are encountered, these are appended to \a error_list_p.
 */
 double
 IsotopicData::getCumulatedProbabilities(IsotopeListCstIteratorPair iter_pair,
@@ -1295,7 +1302,7 @@ IsotopicData::containsName(const QString &name, int &count) const
 \brief Returns a string containing a stanza describing each isotope of \a
 symbol.
 
-\sa Isotope::toString(), Isotope::getMass()
+\sa Isotope::toString, Isotope::getMass
 */
 QString
 IsotopicData::isotopesAsStringBySymbol(const QString &symbol) const
@@ -1442,8 +1449,9 @@ IsotopicData::size() const
 
 /*!
 \brief Returns the validity status of this IsotopicData instance.
-*/
 
+\sa validate(), validateBySymbol(), validateAllBySymbol()
+*/
 bool
 IsotopicData::isValid()
 {
@@ -1489,7 +1497,7 @@ IsotopicData::getUniqueSymbolsCount() const
 
 The validation involves iterating in the whole collection and for each item
 in it invoke its Isotope::validate(). If errors occurred during these
-validations, they are reported as strings in \a error_list.
+validations, they are reported as strings in \a error_list_p.
 
 Return true if no error was encountered, false otherwise.
 */
@@ -1542,7 +1550,7 @@ example, a set of isotopes by the same symbol cannot have a cumulated
 probability different than 1. If that were the case, the error would be
 reported.
 
-Encountered errors are stored in \a error_list.
+Encountered errors are stored in \a error_list_p.
 
 Returns true if validation succeeded, false otherwise.
 
@@ -1592,7 +1600,7 @@ IsotopicData::validateBySymbol(const QString &symbol,
 The validation of the \l{Isotope}s is performed by grouping them
 by symbol. See validateBySymbol().
 
-Encountered errors are stored in \a error_list.
+Encountered errors are stored in \a error_list_p.
 
 Returns true if all the Isotopes validated successfully, false otherwise.
 
