@@ -59,7 +59,7 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::IsotopicDataManualConfigHandler
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup PolChemDefBuildingdBlocks
 \inheaderfile IsotopicDataManualConfigHandler.hpp
 
@@ -126,8 +126,13 @@ character the '#' character. These lines are ignored when loading data.
 */
 
 /*!
-  \variable
-MsXpS::libXpertMassCore::IsotopicDataManualConfigHandler::m_symbolCountMap
+\typealias MsXpS::libXpertMassCore::SymbolCountMap
+
+Alias for to std::map<QString, int>.
+*/
+
+/*!
+  \variable MsXpS::libXpertMassCore::IsotopicDataManualConfigHandler::m_symbolCountMap
 
   Holds symbol/count pairs to document the count of any symbol in the isotopic
 data. This symbol count is stored in the file using the following format:
@@ -675,18 +680,16 @@ IsotopicDataManualConfigHandler::loadData(const QString &file_name)
 /*!
   \brief Write all the IsotopicData to \a file_name.
 
-  If \a file_name is empty, m_fileName is tried. If both are empty, the
-function returns 0. If any one of the file names are correct (file_name takes
-precedence over m_fileName), then m_fileName is set to that file name.
+  If \a file_name is empty, \l{m_fileName} is tried. If both are empty, the
+function returns 0. If any one of the file names are correct (\a file_name takes
+precedence over \l{m_fileName}), then \l{m_fileName} is set to that file name.
 
-  The format of the file consists in a single line of data per \l{Isotope} as
-created using the Isotope::toString() function. Each isotope is output to
+The format of the file consists in a single line of data per \l{Isotope} as
+created using Isotope::toString(). Each isotope is output to
 its own line.
 
-  Returns the count of \l{Isotope}s written to file or 0 if the file does not
+Returns the count of \l{Isotope}s written to file or 0 if the file does not
 exist or is not readable.
-
-  \sa Isotope::Isotope(const QString &text)
 */
 qsizetype
 IsotopicDataManualConfigHandler::writeData(const QString &file_name)
@@ -791,7 +794,8 @@ IsotopicData, then that is an error.
   Returns false if the new chemical data pertain to a \a symbol that was
 already added to the IsotopicData.
 
-  \sa IsotopicData::updateMonoMassMap(), IsotopicData::updateAvgMassMap()
+  \sa IsotopicData::updateMonoMassMap
+  \sa IsotopicData::updateAvgMassMap
 */
 bool
 IsotopicDataManualConfigHandler::newChemicalSet(
