@@ -45,184 +45,132 @@
 /////////////////////// Local includes
 #include "MsXpS/libXpertMassCore/MassDataCborMassSpectrumHandler.hpp"
 
-
 namespace MsXpS
 {
 
 namespace libXpertMassCore
 {
 
-// FIXME TODO DOCUMENTATION
 
+/*!
+\class MsXpS::libXpertMassCore::MassDataCborMassSpectrumHandler
+\inmodule libXpertMassCore
+\ingroup XpertMassCoreUtilities
+\inheaderfile MassDataCborMassSpectrumHandler.hpp
+
+\brief The MassDataCborMassSpectrumHandler class provides features to handle
+mass spectrum data using the CBOR (Concise Binary Object Representation)
+container streaming classes.
+
+The data transported using CBOR is first qualified using the
+\l{Enums::MassDataType::MASS_SPECTRUM} value. The data are packed following that
+mass data type specification.
+
+The format for this kind of CBOR mass spectrum data is the following:
+
+The whole file is actually a map that contains the key/value
+pairs below.
+
+All the text string values below are described in this way in the CBOR Qt
+implementation specification: "Major type 3:  a text string, specifically a
+string of Unicode characters that is encoded as UTF-8 (that is, not a
+QByteArray, but a QString)".
+
+The containers, map, strings and byte arrays dot not need the reader's next()
+call.
+
+The simple value, like integers, do need the reader's next() call.
+
+In this format, the whole data set in the CBOR container is a map with the
+following key/value pairs:
+
+\e{start_map}
+
+\list
+
+\li "DATA_TYPE" / value (quint64) : this quint64
+(QCborStreamReader::UnsignedInteger) value is only got as the very first data bit
+in the file and represents the Enums::MassDataType::MASS_SPECTRUM value
+describing the kind of data encoded in the CBOR container.
+
+\li "TITLE" / value (text string): the title of the mass spectrum that should be
+used to identify it later in a mass data visualization/exploration program like
+MineXpert.
+
+\li "TRACE_COLOR" / value (QByteArray)
+
+\li "X_LABEL" / value (text string): the label of the x abscissae axis.
+
+\li "X_DATA" / value (base64 QByteArray): the array of Base64-encoded m/z values
+(x axis)
+
+\li "Y_LABEL" / value (text string): the label of the y ordinates axis.
+
+\li "Y_DATA" / value (base64 QByteArray): the array of Base64-encoded intensity
+values (y axis)
+\endlist
+
+\e{end_map}
+
+All the data above fully qualify a mass spectrum in order to display it as a
+trace (that is, a graph) in a mass spectrometric data visualization/exploration
+program like MineXpert, from \l{http://www.msxpertsuite.org/}.
+*/
+
+
+/*!
+ \brief Constructs a MassDataCborMassSpectrumHandler instance setting parent to
+ \a parent_p.
+ */
 MassDataCborMassSpectrumHandler::MassDataCborMassSpectrumHandler(
   QObject *parent_p)
   : MassDataCborBaseHandler(parent_p)
 {
+  qDebug() << "Current thread:" << QThread::currentThread()
+           << "is main thread:" << QThread::isMainThread();
 }
 
+/*!
+\brief Constructs a MassDataCborMassSpectrumHandler instance initializing the
+member trace to \a trace and setting parent to \a parent_p.
 
-// When providing a Trace, it is implicit that this is to write that to file.
+\note The \a trace is considered the mass spectrum data to be streamed to a file
+as a CBOR container.
+*/
 MassDataCborMassSpectrumHandler::MassDataCborMassSpectrumHandler(
   QObject *parent_p, const pappso::Trace &trace)
   : MassDataCborBaseHandler(parent_p), m_trace(trace)
 {
 }
 
-
+/*!
+ \brief Destructs the MassDataCborMassSpectrumHandler instance.
+ */
 MassDataCborMassSpectrumHandler::~MassDataCborMassSpectrumHandler()
 {
 }
 
+/*!
+ \brief Decodes the data stream from \a reader_sp.
 
+ The CBOR container consists in a succession of map key/value pairs.
+ The very first key/value pair is
+ "DATA_TYPE"/Enums::MassDataType::MASS_SPECTRUM. The following key/value pairs
+ contain data like the title of the mass spectrum, the color for tracing the
+ mass spectrum, the x (m/z) data and the y (intensity) data. See the class
+ documentation for details.
+
+ Data decoded from the \a reader_sp stream are set to member data for later
+ consumption.
+
+ Returns true if the decoding was successful, false otherwise.
+
+ \sa writeFile()
+ */
 bool
-MassDataCborMassSpectrumHandler::writeFile(const QString &output_file_name)
+MassDataCborMassSpectrumHandler::decodeStream(QCborStreamReaderSPtr &reader_sp)
 {
-  // The format for this kind of CBOR pappso::Trace data is the following:
-
-  // First the quint64 that represents MassDataType. In our specific case, that
-  // must be MassDataType::MASS_SPECTRUM.
-
-  // Then there is the title of data, which is according to the specification:
-  //
-  // Major type 3:  a text string, specifically a string of Unicode characters
-  // that is encoded as UTF-8 (that is, not a QByteArray, but a QString).
-
-  // Then there is a MAP with the following key/value pairs:
-
-  // start_map
-
-  // "X_LABEL" / value (text string)
-  // "Y_LABEL" / value (text string)
-  //
-  // "X_DATA" / value (base64 ByteArray)
-  // "Y_DATA" / value (base64 ByteArray)
-
-  // end_map
-
-  QString local_file_name = output_file_name;
-
-  if(local_file_name.isEmpty())
-    local_file_name = m_outputFileName;
-
-  QFile file(local_file_name);
-
-  bool res = file.open(QIODevice::WriteOnly);
-
-  if(!res)
-    {
-      qDebug() << "Failed to open the file for write.";
-      return false;
-    }
-
-  msp_writer = std::make_shared<QCborStreamWriter>(&file);
-
-  // qDebug() << "Now writing data to file:" << local_file_name;
-
-  // Start of array containing all mapped items
-  msp_writer->startMap(7);
-
-  // First the MassDataType: this is the very *first* data bit in the data
-  // stream.
-  msp_writer->append("DATA_TYPE");
-  msp_writer->append(static_cast<quint64>(MassDataType::MASS_SPECTRUM));
-
-  msp_writer->append("TITLE");
-  msp_writer->append(m_title);
-
-  msp_writer->append("TRACE_COLOR");
-  msp_writer->append(m_colorByteArray);
-
-  msp_writer->append("X_LABEL");
-  msp_writer->append("m/z");
-
-  msp_writer->append("X_DATA");
-  msp_writer->append(m_trace.xAsBase64Encoded());
-
-  msp_writer->append("Y_LABEL");
-  msp_writer->append("intensity");
-
-  msp_writer->append("Y_DATA");
-  msp_writer->append(m_trace.yAsBase64Encoded());
-
-  msp_writer->endMap();
-  // Close the map now.
-
-  file.close();
-
-  return res;
-}
-
-
-void
-MassDataCborMassSpectrumHandler::writeByteArray(QByteArray &byte_array)
-{
-  msp_writer = std::make_shared<QCborStreamWriter>(&byte_array);
-
-  // qDebug() << "Now writing data byte array.";
-
-  // Start of array containing all mapped items
-  msp_writer->startMap(7);
-
-  // First the MassDataType: this is the very *first* data bit in the data
-  // stream.
-  msp_writer->append("DATA_TYPE");
-  msp_writer->append(static_cast<quint64>(MassDataType::MASS_SPECTRUM));
-
-  msp_writer->append("TITLE");
-  msp_writer->append(m_title);
-
-  msp_writer->append("TRACE_COLOR");
-  msp_writer->append(m_colorByteArray);
-
-  msp_writer->append("X_LABEL");
-  msp_writer->append("m/z");
-
-  msp_writer->append("X_DATA");
-  msp_writer->append(m_trace.xAsBase64Encoded());
-
-  msp_writer->append("Y_LABEL");
-  msp_writer->append("intensity");
-
-  msp_writer->append("Y_DATA");
-  msp_writer->append(m_trace.yAsBase64Encoded());
-
-  msp_writer->endMap();
-  // Close the map now.
-}
-
-
-bool
-MassDataCborMassSpectrumHandler::readContext(QCborStreamReaderSPtr &reader_sp)
-{
-  // The format for this kind of CBOR pappso::Trace data is the following:
-
-  // The whole file is actually a map that contains the key/value
-  // pairs below.
-
-  // The text string values below are described in this way in the specif:
-  // Major type 3:  a text string, specifically a string of Unicode characters
-  // that is encoded as UTF-8 (that is, not a QByteArray, but a QString).
-
-  // The containers, map, strings and byte arrays dot not need the reader to
-  // explicitely advance to next().
-
-  // The simple value, like integers, do need that reader's next() call.
-
-  // So now, the MAP with the following key/value pairs:
-
-  // start_map
-
-  // "DATA_TYPE" / value (quint64)
-  // "TITLE" / value (text string)
-  // "X_LABEL" / value (text string)
-  // "Y_LABEL" / value (text string)
-  //
-  // "X_DATA" / value (base64 ByteArray)
-  // "Y_DATA" / value (base64 ByteArray)
-
-  // end_map
-
-  // These are needed to store the x and y data as two different byte arrays.
+  // See QDoc class description above
 
   while(reader_sp->lastError() == QCborError::NoError && reader_sp->hasNext())
     {
@@ -233,26 +181,32 @@ MassDataCborMassSpectrumHandler::readContext(QCborStreamReaderSPtr &reader_sp)
         {
           // In this format, the QCborStreamReader::UnsignedInteger datum is
           // only got as the very first data bit in the file. This bit of
-          // information is a quint64 representing MassDataType::MASS_SPECTRUM.
+          // information is a quint64 representing
+          // Enums::MassDataType::MASS_SPECTRUM.
 
           // Now check that the read value actually corresponds to the expected
           // mass data type for which this object is working!
 
+          // The m_currentKey value was set in a previous loop iteration below
+          // where the type of data read from the stream was the string key
+          // "DATA_TYPE" and we now, for this loop iteratation get the value
+          // for that key.
           if(m_currentKey == "DATA_TYPE")
             {
               // quint64 data_type = 0;
               // data_type = reader_sp->toUnsignedInteger();
               // qDebug() << "The mass data type:" << data_type;
 
-              if(static_cast<MassDataType>(reader_sp->toUnsignedInteger()) !=
-                 MassDataType::MASS_SPECTRUM)
+              if(static_cast<Enums::MassDataType>(
+                   reader_sp->toUnsignedInteger()) !=
+                 Enums::MassDataType::MASS_SPECTRUM)
                 {
                   qDebug()
                     << "The expected DATA_TYPE::MASS_SPECTRUM was not found.";
                   return false;
                 }
 
-              m_massDataType = MassDataType::MASS_SPECTRUM;
+              m_massDataType = Enums::MassDataType::MASS_SPECTRUM;
 
               m_currentKey = QString();
             }
@@ -263,6 +217,8 @@ MassDataCborMassSpectrumHandler::readContext(QCborStreamReaderSPtr &reader_sp)
           // We had what we wanted, go to next.
           reader_sp->next();
         }
+      // End of
+      // if(type == QCborStreamReader::UnsignedInteger)
       else if(type == QCborStreamReader::String)
         {
           // Read a CBOR string, concatenating all
@@ -271,8 +227,8 @@ MassDataCborMassSpectrumHandler::readContext(QCborStreamReaderSPtr &reader_sp)
           auto chunk = reader_sp->readString();
           while(chunk.status == QCborStreamReader::Ok)
             {
-              str += chunk.data;
-              chunk = reader_sp->readString();
+              str   += chunk.data;
+              chunk  = reader_sp->readString();
             }
 
           if(chunk.status == QCborStreamReader::Error)
@@ -357,27 +313,13 @@ MassDataCborMassSpectrumHandler::readContext(QCborStreamReaderSPtr &reader_sp)
 
           m_currentKey = QString();
         }
-
-      // The MAP has the following key/value pairs:
-
-      // start_map
-
-      // "TITLE" / value (text string)
-      // "X_LABEL" / value (text string)
-      // "Y_LABEL" / value (text string)
-      //
-      // "X_DATA" / value (base64 ByteArray)
-      // "Y_DATA" / value (base64 ByteArray)
-
-      // end_map
-
       else if(type == QCborStreamReader::Map)
         {
 
           reader_sp->enterContainer();
 
           // Read elements until end of map is reached
-          bool res = readContext(reader_sp);
+          bool res = decodeStream(reader_sp);
           if(res)
             reader_sp->leaveContainer();
           else
@@ -400,13 +342,135 @@ MassDataCborMassSpectrumHandler::readContext(QCborStreamReaderSPtr &reader_sp)
   return !reader_sp->lastError();
 }
 
+/*!
+ \brief Writes member data to file \a output_file_name.
 
+ \note The member data are packed in a CBOR container and streamed to the file
+ as a set of key/value pairs that form the CBOR map being streamed to the file.
+
+ Returns true if the operation was successful, false, otherwise.
+ */
+bool
+MassDataCborMassSpectrumHandler::writeFile(const QString &output_file_name)
+{
+  QString local_file_name = output_file_name;
+
+  if(local_file_name.isEmpty())
+    local_file_name = m_outputFileName;
+
+  QFile file(local_file_name);
+
+  bool res = file.open(QIODevice::WriteOnly);
+
+  if(!res)
+    {
+      qDebug() << "Failed to open the file for write.";
+      return false;
+    }
+
+  msp_writer = std::make_shared<QCborStreamWriter>(&file);
+
+  // qDebug() << "Now writing data to file:" << local_file_name;
+
+  // Start of array containing all mapped items
+  msp_writer->startMap(7);
+
+  // First the Enums::MassDataType: this is the very *first* data bit in the
+  // data stream.
+  msp_writer->append("DATA_TYPE");
+  msp_writer->append(static_cast<quint64>(Enums::MassDataType::MASS_SPECTRUM));
+
+  msp_writer->append("TITLE");
+  msp_writer->append(m_title);
+
+  msp_writer->append("TRACE_COLOR");
+  msp_writer->append(m_colorByteArray);
+
+  msp_writer->append("X_LABEL");
+  msp_writer->append("m/z");
+
+  msp_writer->append("X_DATA");
+  msp_writer->append(m_trace.xAsBase64Encoded());
+
+  msp_writer->append("Y_LABEL");
+  msp_writer->append("intensity");
+
+  msp_writer->append("Y_DATA");
+  msp_writer->append(m_trace.yAsBase64Encoded());
+
+  msp_writer->endMap();
+  // Close the map now.
+
+  file.close();
+
+  return res;
+}
+
+/*!
+ \brief Writes member data to byte array \a byte_array.
+
+ \note The member data are packed in a CBOR container and streamed to the byte
+ array as a set of key/value pairs that form the CBOR map being streamed to the
+ byte array.
+ */
+void
+MassDataCborMassSpectrumHandler::writeByteArray(QByteArray &byte_array)
+{
+  msp_writer = std::make_shared<QCborStreamWriter>(&byte_array);
+
+  // qDebug() << "Now writing data byte array.";
+
+  // Start of array containing all mapped items
+  msp_writer->startMap(7);
+
+  // First the Enums::MassDataType: this is the very *first* data bit in the
+  // data stream.
+  msp_writer->append("DATA_TYPE");
+  msp_writer->append(static_cast<quint64>(Enums::MassDataType::MASS_SPECTRUM));
+
+  msp_writer->append("TITLE");
+  msp_writer->append(m_title);
+
+  msp_writer->append("TRACE_COLOR");
+  msp_writer->append(m_colorByteArray);
+
+  msp_writer->append("X_LABEL");
+  msp_writer->append("m/z");
+
+  msp_writer->append("X_DATA");
+  msp_writer->append(m_trace.xAsBase64Encoded());
+
+  msp_writer->append("Y_LABEL");
+  msp_writer->append("intensity");
+
+  msp_writer->append("Y_DATA");
+  msp_writer->append(m_trace.yAsBase64Encoded());
+
+  msp_writer->endMap();
+  // Close the map now.
+}
+
+/*!
+ \brief Reads data from the byte array \a byte_array.
+
+ The data in \a byte_array are packed in a CBOR container. These data have
+ typically travelled over the network and the receiving end needs to unpack the
+ data in that \a byte_array. This is what this function does.
+
+ The data unpacked from \a byte_array are stored in this object member variables
+ for later consumption by the user of this function.
+
+A CBOR stream reader is allocated and set to decode \a byte_array. The actual
+decoding occurs in \l{decodeStream()}.
+
+Returns true if the operations was successful, false otherwise.
+ */
 bool
 MassDataCborMassSpectrumHandler::readByteArray(const QByteArray &byte_array)
 {
   msp_reader = std::make_shared<QCborStreamReader>(byte_array);
 
-  bool res = readContext(msp_reader);
+  bool res = decodeStream(msp_reader);
 
   // qDebug() << "After finishing the read, m_title is:" << m_title
   //<< "and mass data type is:" << static_cast<quint64>(m_massDataType);
@@ -446,14 +510,24 @@ MassDataCborMassSpectrumHandler::readByteArray(const QByteArray &byte_array)
   return res;
 }
 
+/*!
+ \brief Reads the data in file \a input_file_name by decoding the data stream
+ read from it.
+ This function first decodes the data in the CBOR container stored in the
+ file. Then it decodes the Base64-encoded x and y axis data into the member
+ pappso::Trace object.
 
+ Returns true if the operation was successful, false, otherwise.
+
+ \sa decodeStream(), readByteArray()
+ */
 bool
 MassDataCborMassSpectrumHandler::readFile(const QString &input_file_name)
 {
   // The format for this kind of CBOR pappso::Trace data is the following:
 
-  // First the quint64 that represents MassDataType. In our specific case, that
-  // must be MassDataType::MASS_SPECTRUM.
+  // First the quint64 that represents Enums::MassDataType. In our specific
+  // case, that must be Enums::MassDataType::MASS_SPECTRUM.
 
   // Then there is the title of data, which is according to the specification:
   //
@@ -500,7 +574,7 @@ MassDataCborMassSpectrumHandler::readFile(const QString &input_file_name)
 
   msp_reader = std::make_shared<QCborStreamReader>(&file);
 
-  res = readContext(msp_reader);
+  res = decodeStream(msp_reader);
 
   file.close();
 
@@ -542,55 +616,73 @@ MassDataCborMassSpectrumHandler::readFile(const QString &input_file_name)
   return res;
 }
 
-
+/*!
+\brief Sets the abscissae \a label for the mass spectrum data.
+*/
 void
 MassDataCborMassSpectrumHandler::setXLabel(const QString &label)
 {
   m_xLabel = label;
 }
 
-
+/*!
+\brief Returns the abscissae label for the mass spectrum data.
+*/
 QString
 MassDataCborMassSpectrumHandler::getXLabel() const
 {
   return m_xLabel;
 }
 
-
+/*!
+\brief Sets the ordinates \a label for the mass spectrum data.
+*/
 void
 MassDataCborMassSpectrumHandler::setYLabel(const QString &label)
 {
   m_yLabel = label;
 }
 
-
+/*!
+\brief Returns the ordinates label for the mass spectrum data.
+*/
 QString
 MassDataCborMassSpectrumHandler::getYLabel() const
 {
   return m_yLabel;
 }
 
+/*!
+\brief Sets the mass spectrum data to \a trace.
+*/
 void
 MassDataCborMassSpectrumHandler::setTrace(const pappso::Trace &trace)
 {
   m_trace = trace;
 }
 
-
+/*!
+\brief Returns the mass spectrum data.
+*/
 pappso::Trace
 MassDataCborMassSpectrumHandler::getTrace() const
 {
   return m_trace;
 };
 
-
+/*!
+\brief Clears the mass spectrum data.
+*/
 void
 MassDataCborMassSpectrumHandler::clearTrace()
 {
   m_trace.clear();
 }
 
-
+/*!
+\brief Sets the color with which the mass spectrum data must be displayed. The
+color i encoded as the \a color_byte_array byte array.
+*/
 void
 MassDataCborMassSpectrumHandler::setTraceColor(
   const QByteArray &color_byte_array)
@@ -598,7 +690,9 @@ MassDataCborMassSpectrumHandler::setTraceColor(
   m_colorByteArray = color_byte_array;
 }
 
-
+/*!
+\brief Returns the color with which the mass spectrum data must be displayed.
+*/
 QByteArray
 MassDataCborMassSpectrumHandler::getTraceColor() const
 {
