@@ -82,8 +82,8 @@ int FWHM_PEAK_SPAN_FACTOR = 4;
 
 /*!
 \class MsXpS::libXpertMassCore::MassPeakShaperConfig
-\inmodule libXpertMass
-\ingroup XpertMassMassCalculations
+\inmodule libXpertMassCore
+\ingroup XpertMassCoreMassCalculations
 \inheaderfile MassPeakShaperConfig.hpp
 
 \brief The MassPeakShaperConfig class provides the features required to
@@ -264,6 +264,10 @@ MassPeakShaperConfig::initialize(const MassPeakShaperConfig &other)
   return *this;
 }
 
+/*!
+\brief Returns a newly allocated MassPeakShaperConfig instance initialized using
+\a other and with parent set to \a parent.
+*/
 MassPeakShaperConfig *
 MassPeakShaperConfig::clone(const MassPeakShaperConfig &other,
                             QObject *parent) const
@@ -464,7 +468,7 @@ MassPeakShaperConfig::getReferencePeakMz() const
 \brief Sets the requirement to prepare m/z bins at a later computing stage to
 \a with_bins.
 
-\sa IsotopicClusterShaper::run()
+\sa IsotopicClusterShaper::run(), isWithBins()
 */
 void
 MassPeakShaperConfig::setWithBins(bool with_bins)
@@ -475,7 +479,7 @@ MassPeakShaperConfig::setWithBins(bool with_bins)
 /*!
 \brief Returns the requirement to prepare m/z bins at a later computing stage.
 
-\sa IsotopicClusterShaper::run()
+\sa IsotopicClusterShaper::run(), setWithBins()
 */
 bool
 MassPeakShaperConfig::isWithBins() const
@@ -815,6 +819,8 @@ MassPeakShaperConfig::gamma(bool *ok)
 
 The m/z step value is the distance between two consecutive points in the peak
 shape.
+
+\sa getMzStep()
 */
 void
 MassPeakShaperConfig::setMzStep(double mz_step)
@@ -827,6 +833,8 @@ MassPeakShaperConfig::setMzStep(double mz_step)
 
 The m/z step value is the distance between two consecutive points in the peak
 shape.
+
+\sa setMzStep()
 */
 double
 MassPeakShaperConfig::getMzStep() const
@@ -918,7 +926,7 @@ c, a, gamma.
 Returns true if the computation was successful, false otherwise.
 */
 bool
-MassPeakShaperConfig::resolve()
+MassPeakShaperConfig::resolve(libXpertMassCore::ErrorList &error_list)
 {
   // We need to try to set all the relevant parameters by calculation.
 
@@ -927,13 +935,22 @@ MassPeakShaperConfig::resolve()
   // These are the essential parameters:
 
   if(!m_referencePeakMz)
-    return false;
+    {
+      error_list.append("Missing reference peak m/z value");
+      return false;
+    }
 
   if(!m_fwhm && !m_resolution)
-    return false;
+    {
+      error_list.append("Both FWHM and resolution are naught");
+      return false;
+    }
 
   if(!m_pointCount)
-    return false;
+    {
+      error_list.append("The count of points to shape the peak is naught");
+      return false;
+    }
 
   // At this point we should be able to compute the relevant data.
 
@@ -947,7 +964,10 @@ MassPeakShaperConfig::resolve()
       resolution(&ok);
 
       if(!ok)
-        return false;
+        {
+          error_list.append("Failed to compute resolution value");
+          return false;
+        }
     }
   else
     {
@@ -956,7 +976,10 @@ MassPeakShaperConfig::resolve()
       fwhm(&ok);
 
       if(!ok)
-        return false;
+        {
+          error_list.append("Failed to compute FWHM value");
+          return false;
+        }
     }
 
   // Now check if we have and can compute the bins.
@@ -968,29 +991,43 @@ MassPeakShaperConfig::resolve()
   binSize(&ok);
 
   if(!ok)
-    return false;
+    {
+      error_list.append("Failed to compute the bin size");
+      return false;
+    }
 
   mzStep(&ok);
 
   if(!ok)
-    return false;
-
+    {
+      error_list.append("Failed to compute the m/z step");
+      return false;
+    }
   // Now the other parameters for the shape.
 
   c(&ok);
 
   if(!ok)
-    return false;
+    {
+      error_list.append("Failed to compute the c parameter");
+      return false;
+    }
 
   a(&ok);
 
   if(!ok)
-    return false;
+    {
+      error_list.append("Failed to compute the a parameter");
+      return false;
+    }
 
   gamma(&ok);
 
   if(!ok)
-    return false;
+    {
+      error_list.append("Failed to compute the gamma parameter");
+      return false;
+    }
 
   return true;
 }
@@ -998,14 +1035,17 @@ MassPeakShaperConfig::resolve()
 /*!
 \brief Returns a string representing this MassPeakShaperConfig instance.
 
-No verification whatsoever is performed.
+The configuration of the MassPeakShaper is first resolved. If that step fails,
+an empty string is returned, otherwise the configuration is returned as a
+string.
 */
 QString
 MassPeakShaperConfig::toString()
 {
   QString string;
 
-  bool ok = resolve();
+  libXpertMassCore::ErrorList error_list;
+  bool ok = resolve(error_list);
 
   if(!ok)
     return QString();
