@@ -1037,6 +1037,11 @@ Monomer::validate(ErrorList *error_list_p) const
   return m_isValid;
 }
 
+/*!
+\brief Returns the validity status of this Monomer.
+
+\sa validate()
+*/
 bool
 Monomer::isValid() const
 {
@@ -2109,6 +2114,9 @@ Monomer::removeModif(ModifSPtr modif_sp)
   return true;
 }
 
+/*!
+\brief Clears all the data of the Monomer instance.
+*/
 void
 Monomer::clear()
 {
@@ -2125,6 +2133,9 @@ Monomer::clear()
   m_isValid = false;
 }
 
+/*!
+\brief Returns a text string representing this Monomer instance.
+*/
 QString
 Monomer::toString() const
 {
