@@ -44,7 +44,7 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::Oligomer
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup PolChemDefBuildingdBlocks
 \inheaderfile Oligomer.hpp
 
@@ -126,7 +126,7 @@ to the sequence of its "enclosing" \l Polymer.
 \variable MsXpS::libXpertMassCore::Oligomer::m_partialCleavage
 
 \brief Stores the partial cleavage out of which the Oligomer has been obtained
-if that process was a chemical cleavage.
+if that process was a (bio)-chemical cleavage.
 */
 
 /*!
@@ -218,6 +218,11 @@ Oligomer::~Oligomer()
 }
 
 //////////////// THE POLYMER /////////////////////
+/*!
+\brief Set the \l{PolChemDef} \l{mcsp_polymer} member to \a polymer_cqsp.
+
+\sa getPolymerCstSPtr()
+*/
 void
 Oligomer::setPolymerCstSPtr(PolymerCstQSPtr polymer_cqsp)
 {
@@ -226,6 +231,8 @@ Oligomer::setPolymerCstSPtr(PolymerCstQSPtr polymer_cqsp)
 
 /*!
 \brief Returns the polymer.
+
+\sa getPolymerCstSPtr()
 */
 const PolymerCstQSPtr &
 Oligomer::getPolymerCstSPtr() const
@@ -267,7 +274,6 @@ Oligomer::setDescription(const QString &description)
 /*!
 \brief Returns the description.
 */
-
 QString
 Oligomer::getDescription() const
 {
@@ -297,7 +303,7 @@ otherwise it is set to false. That m_isModified value is then returned.
 
 If \a deep is false, the value of m_isModified is immediately returned.
 
-\sa Polymer::modifiedMonomerCount(), Monomer::isModified()
+\sa Polymer::hasModifiedMonomer, Monomer::isModified()
 */
 bool
 Oligomer::isModified(bool deep /*false*/) const
@@ -321,6 +327,11 @@ Oligomer::isModified(bool deep /*false*/) const
   return m_isModified;
 }
 
+/*!
+\brief Return the count of the \l{Polymer}'s \l{Sequence}'s \l{Monomer}
+instances that are modified.
+\sa Polymer::modifiedMonomerCount
+*/
 std::size_t
 Oligomer::modifiedMonomerCount() const
 {
@@ -443,7 +454,6 @@ Oligomer::setIndexRange(const IndexRange &index_range)
 /*!
 \brief Returns a const reference to the IndexRangeCollection.
 */
-
 const IndexRangeCollection &
 Oligomer::getIndexRangeCollectionCstRef() const
 {
@@ -583,7 +593,7 @@ Oligomer::setCalcOptions(const CalcOptions &calc_options)
 }
 
 /*!
-\brief Returns the CalcOptions.
+\brief Returns the CalcOptions member.
 */
 const CalcOptions &
 Oligomer::getCalcOptionsCstRef() const
@@ -591,6 +601,9 @@ Oligomer::getCalcOptionsCstRef() const
   return m_calcOptions;
 }
 
+/*!
+\brief Returns a reference to the CalcOptions member.
+*/
 CalcOptions &
 Oligomer::getCalcOptionsRef()
 {
@@ -598,6 +611,11 @@ Oligomer::getCalcOptionsRef()
 }
 
 //////////////// THE MASSES /////////////////////
+/*!
+\brief Set the mass qualified using \a mass_type to the \a mass value.
+
+\sa setMasses()
+*/
 void
 Oligomer::setMass(Enums::MassType mass_type, double mass)
 {
@@ -609,6 +627,11 @@ Oligomer::setMass(Enums::MassType mass_type, double mass)
     qFatalStream() << "The mass_type needs to be either MONO or AVG.";
 }
 
+/*!
+ \brief Sets \a mono and \a avg masses to this Oligomer.
+
+ \sa setMass()
+ */
 void
 Oligomer::setMasses(double mono, double avg)
 {
@@ -699,12 +722,18 @@ Oligomer::addCrossLink(CrossLinkSPtr cross_link_sp)
 }
 
 //////////////// THE PARTIAL CLEAVAGE /////////////////////
+/*!
+\brief Set the member \l m_partialCleavage to \a partial_cleavage.
+*/
 void
 Oligomer::setPartialCleavage(std::size_t partial_cleavage)
 {
   m_partialCleavage = partial_cleavage;
 }
 
+/*!
+\brief Returns the m_partialCleavage member.
+*/
 std::size_t
 Oligomer::getPartialCleavage() const
 {
@@ -712,24 +741,36 @@ Oligomer::getPartialCleavage() const
 }
 
 //////////////// THE FORMULA /////////////////////
+/*!
+\brief Sets the formula to \a formula.
+*/
 void
 Oligomer::setFormula(const Formula &formula)
 {
   m_formula = formula;
 }
 
+/*!
+ \brief Sets the formula to \a formula_string.
+ */
 void
 Oligomer::setFormula(const QString &formula_string)
 {
   m_formula = Formula(formula_string);
 }
 
+/*!
+\brief Returns a constant reference to the formula.
+*/
 const Formula &
 Oligomer::getFormulaCstRef() const
 {
   return m_formula;
 }
 
+/*!
+ \brief Returns a reference to the formula.
+ */
 Formula &
 Oligomer::getFormulaRef()
 {
@@ -885,7 +926,7 @@ Oligomer::elementalComposition(const CalcOptions &calc_options,
     qInfo() << "Enums::SelectionType::OLIGOMERS";
 
   qDebug() << "Going to call Polymer::elementalComposition() with CalcOptions:"
-           << calc_options.toString();
+           << calc_options.toString() << "and ionizer:" << ionizer.toString();
 
   return mcsp_polymer->elementalComposition(calc_options, ionizer);
 }
