@@ -65,7 +65,7 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::PolChemDef
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup PolChemDef
 \inheaderfile PolChemDef.hpp
 
@@ -836,7 +836,8 @@ the string list, otherwise it is skipped. The masses that are compared
 between every two monomers is of \a mass_type.
 */
 QStringList
-PolChemDef::differenceBetweenMonomers(double threshold, Enums::MassType mass_type)
+PolChemDef::differenceBetweenMonomers(double threshold,
+                                      Enums::MassType mass_type)
 {
   //     qDebug()
   // 	     << "threshold" << threshold;
@@ -1704,8 +1705,9 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
 
       qDebug() << "Rendered CrossLinker: " << crossLinker_sp->getName()
                << "with formula:" << crossLinker_sp->getFormula()
-               << "with masses:" << crossLinker_sp->getMass(Enums::MassType::MONO)
-               << "/" << crossLinker_sp->getMass(Enums::MassType::AVG);
+               << "with masses:"
+               << crossLinker_sp->getMass(Enums::MassType::MONO) << "/"
+               << crossLinker_sp->getMass(Enums::MassType::AVG);
 
       indentedChild = indentedChild.nextSiblingElement();
     }
@@ -2140,7 +2142,8 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
 
       // qDebug() << "Rendered CrossLinker: " << crossLinker_csp->getName()
       //          << "with formula:" << crossLinker_csp->getFormula()
-      //          << "with masses:" << crossLinker_csp->getMass(Enums::MassType::MONO)
+      //          << "with masses:" <<
+      //          crossLinker_csp->getMass(Enums::MassType::MONO)
       //          << "/" << crossLinker_csp->getMass(Enums::MassType::AVG);
 
       indentedChild = indentedChild.nextSiblingElement();
@@ -2723,87 +2726,111 @@ PolChemDef::writeXmlFile()
   return true;
 }
 
+/*!
+\brief Validates this PolChemDef instance by checking the validity of all its
+members data. Returns true if validation was successful, false otherwise. Any
+error is added to \a error_list_p if non-nullptr.
+*/
 bool
 PolChemDef::validate(ErrorList *error_list_p) const
 {
+  // So we can return immediately upon error.
+  m_isValid = false;
+
   if(m_isotopicDataFilePath.isEmpty())
     {
-      error_list_p->push_back("The IsotopicData file path is empty.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The IsotopicData file path is empty.");
       return false;
     }
 
   QFileInfo file_info(m_isotopicDataFilePath);
   if(!file_info.exists())
     {
-      error_list_p->push_back("The IsotopicData file cannot be found.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The IsotopicData file cannot be found.");
       return false;
     }
 
   if(msp_isotopicData == nullptr || msp_isotopicData.get() == nullptr)
     {
-      error_list_p->push_back("The IsotopicData are not available.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The IsotopicData are not available.");
       return false;
     }
 
   if(m_name.isEmpty())
     {
-      error_list_p->push_back("The PolChemDef name is empty.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The PolChemDef name is empty.");
       return false;
     }
 
   if(m_xmlDataFilePath.isEmpty())
     {
-      error_list_p->push_back("The PolChemDef file path is empty.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The PolChemDef file path is empty.");
       return false;
     }
 
   file_info.setFile(m_xmlDataFilePath);
   if(!file_info.exists())
     {
-      error_list_p->push_back("The PolChemDef file cannot be found.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The PolChemDef file cannot be found.");
       return false;
     }
 
   if(!m_leftCap.validate(msp_isotopicData, error_list_p))
     {
-      error_list_p->push_back("The left cap formula failed to validate.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The left cap formula failed to validate.");
       return false;
     }
 
   if(!m_rightCap.validate(msp_isotopicData, error_list_p))
     {
-      error_list_p->push_back("The right cap formula failed to validate.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The right cap formula failed to validate.");
       return false;
     }
 
   if(m_codeLength < 1)
     {
-      error_list_p->push_back("The code length is less than 1.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The code length is less than 1.");
       return false;
     }
 
   if(!m_ionizer.validate(error_list_p))
     {
-      error_list_p->push_back("The ionization rule failed to validate.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("The ionization rule failed to validate.");
       return false;
     }
 
   if(!m_modifs.size())
     {
-      error_list_p->push_back("There is not a single Modif instance.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("There is not a single Modif instance.");
       return false;
     }
 
   if(!m_monomers.size())
     {
-      error_list_p->push_back("There is not a single Monomer instance.");
+      if(error_list_p != nullptr)
+        error_list_p->push_back("There is not a single Monomer instance.");
       return false;
     }
 
+  // Good!
   m_isValid = true;
   return m_isValid;
 }
 
+/*!
+\brief Returns the validity status of thie PolChemDef instance.
+*/
 bool
 PolChemDef::isValid() const
 {
