@@ -42,14 +42,14 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::Prop
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup ThePropSystem
 \inheaderfile Prop.hpp
 
 \brief The Prop class is the abstract base class for a number of specialized
 properties.
 
-Properties are libXpertMass' way of extending the capabilities of
+Properties are libXpertMassCore' way of extending the capabilities of
 objects. A property is merely an encapsulation of:
 
 \list
@@ -241,7 +241,7 @@ Prop::formatXmlElement([[maybe_unused]] int offset,
 
 /*!
 \class MsXpS::libXpertMassCore::StringProp
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup ThePropSystem
 
 \brief The StringProp class is the specialized class for properties
@@ -499,7 +499,7 @@ StringProp::formatXmlElement(int offset, const QString &indent)
 
 /*!
 \class MsXpS::libXpertMassCore::IntProp
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup ThePropSystem
 
 \brief The IntProp class is the specialized class for properties
@@ -735,7 +735,7 @@ IntProp::formatXmlElement(int offset, const QString &indent)
 
 /*!
 \class MsXpS::libXpertMassCore::DoubleProp
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup ThePropSystem
 
 \brief The DoubleProp class is the specialized class for properties
@@ -973,7 +973,7 @@ DoubleProp::formatXmlElement(int offset, const QString &indent)
 
 /*!
 \class MsXpS::libXpertMassCore::NoDeletePointerProp
-\inmodule libXpertMass
+\inmodule libXpertMassCore
 \ingroup ThePropSystem
 
 \brief The NoDeletePointerProp class provides a pointer property.
