@@ -646,7 +646,6 @@ index is for the \e same Monomer object (pointer-wise). If the Monomer was
 found, the returned value is certain to be correct and \a ok is set to true. If
 the Monomer was not found, the returned value is 0 and ok is set to false.
 */
-
 std::size_t
 Sequence::monomerIndex(MonomerCstSPtr monomer_csp, bool &ok) const
 {
@@ -884,7 +883,7 @@ Returns true.
 bool
 Sequence::removeMonomerAt(std::size_t index)
 {
-  //  qDebug() << "20250514 - Asking to remove Monomer at index" << index;
+  //  qDebug() << "Asking to remove Monomer at index" << index;
 
   if(index >= size())
     qFatalStream() << "Programming error. Index is out of bounds.";
@@ -895,7 +894,7 @@ Sequence::removeMonomerAt(std::size_t index)
 
   MonomerSPtr monomer_sp = m_monomers.at(index);
 
-  qDebug() << "20250514 - The Monomer being removed at index:" << index
+  qDebug() << "The Monomer being removed at index:" << index
            << "is:" << monomer_sp->getName()
            << "with modification status:" << monomer_sp->isModified();
 
@@ -920,7 +919,7 @@ Sequence::removeMonomerAt(std::size_t index)
   m_uuidMonomerPairs.erase(the_iterator_cst);
   m_monomers.erase(m_monomers.begin() + index);
 
-  //  qDebug() << "20250514 - Done removing Monomer.";
+  //  qDebug() << "Done removing Monomer.";
 
   return true;
 }
@@ -1034,7 +1033,6 @@ container of Monomer instances is set to \a index.
 Returns -1 if an error occurred, 1 if \a sequence_motif was found in this
 Sequence, 0 otherwise.
 */
-
 int
 Sequence::findForwardMotif(const Sequence &sequence_motif,
                            std::size_t &index) const
