@@ -54,8 +54,8 @@ namespace libXpertMassCore
 
 /*!
 \class MsXpS::libXpertMassCore::Utils
-\inmodule libXpertMass
-\ingroup XpertMassUtilities
+\inmodule libXpertMassCore
+\ingroup XpertMassCoreUtilities
 \inheaderfile Utils.hpp
 
 \brief The Utils class provides a number of utilitary features that may be of
@@ -73,7 +73,7 @@ This regular expression does not account for the \"<text>\" title
 of the actionformula.
 
 \code
-  "([+-]?)([A-Z][a-z]*)(\\d*[\\.]?\\d*)"
+"([+-]?)([A-Z][a-z]*)(\\d*[\\.]?\\d*)"
 \endcode
 
 \sa Formula::splitActionParts()
@@ -93,7 +93,7 @@ QRegularExpression Utils::xyFormatMassDataRegExp =
 \variable MsXpS::libXpertMassCore::Utils::endOfLineRegExp
 
 \brief Regular expression that matches the end of line in text files.
- */
+*/
 QRegularExpression Utils::endOfLineRegExp = QRegularExpression("^\\s+$");
 
 
@@ -101,19 +101,19 @@ QRegularExpression Utils::endOfLineRegExp = QRegularExpression("^\\s+$");
 \variable MsXpS::libXpertMassCore::Utils::xmlIndentationToken
 
 \brief String used to craft the indentation of the XML elements.
- */
+*/
 QString Utils::xmlIndentationToken = QString(" ");
 
 /*!
- \brief Constructs a Utils instance.
- */
+\brief Constructs a Utils instance setting parent to \a parent.
+*/
 Utils::Utils(QObject *parent): QObject(parent)
 {
 }
 
 /*!
 \brief Destructs a Utils instance.
- */
+*/
 Utils::~Utils()
 {
 }
@@ -130,8 +130,7 @@ parameters.
 
 \li \a msg The message to output.
 \endlist
-
- */
+*/
 void
 Utils::messageOutputFormat(QtMsgType type,
                            const QMessageLogContext &context,
@@ -225,7 +224,7 @@ All the values in list are process in order to compute the following:
 statistical values if the corresponding parameters are non-nullptr.
 
 \sa doubleVectorStatistics()
- */
+*/
 void
 Utils::doubleListStatistics(QList<double> list,
                             double &sum,
@@ -312,7 +311,7 @@ All the values in the container are processed in order to compute the following:
 statistical values if the corresponding parameters are non-nullptr.
 
 \sa doubleListStatistics()
- */
+*/
 void
 Utils::doubleVectorStatistics(std::vector<double> &vector,
                               double &sum,
@@ -384,7 +383,7 @@ Utils::doubleVectorStatistics(std::vector<double> &vector,
 within the double representation capabilities of the platform, false otherwise.
 
 In the comparison, the \a decimal_places are taken into account.
- */
+*/
 bool
 Utils::almostEqual(double value1, double value2, int decimal_places)
 {
@@ -443,7 +442,7 @@ qStdOut() << __FILE__ << __LINE__
 
 Returns a reference to a static QTextStream that directs to the standard
 output.
- */
+*/
 QTextStream &
 Utils::qStdOut()
 {
@@ -454,7 +453,7 @@ Utils::qStdOut()
 /*!
 \brief Removes all space characters from a copy of the \a text string and
 returns the new string.
- */
+*/
 QString
 Utils::unspacify(const QString &text)
 {
@@ -471,7 +470,7 @@ Utils::unspacify(const QString &text)
 
 /*!
 \brief Returns a string with a binary representation of the \a value integer.
- */
+*/
 QString
 Utils::binaryRepresentation(int value)
 {
@@ -497,7 +496,7 @@ are too many details", becomes "Interes...details".
 
 \a delimiter string to use as the elision delimiter (in the above example, that
 is '.').
- */
+*/
 QString
 Utils::elideText(const QString &text,
                  int chars_left,
@@ -538,7 +537,7 @@ length, inserts newline characters at positions calculated to yield a
 paragraph of the given \a width.
 
 \sa stanzifyParagraphs()
- */
+*/
 QString
 Utils::stanzify(const QString &text, int width)
 {
@@ -585,7 +584,7 @@ reduced to a set of lines to make a pararagraph (see \l{stanzify}). The with of
 the line in that generated paragraph is \a width.
 
 \sa stanzify()
- */
+*/
 QString
 Utils::stanzifyParagraphs(const QString &text, int width)
 {
@@ -615,7 +614,7 @@ For example, 0.11 would return 0 (no empty decimal)
 2.001 would return 2
 
 1000.0001254 would return 3
- */
+*/
 int
 Utils::countZeroDecimals(double value)
 {
@@ -642,7 +641,7 @@ Utils::countZeroDecimals(double value)
 /*!
 \brief Returns the delta value corresponding to \a value and \a ppm
 part-per-million.
- */
+*/
 double
 Utils::ppm(double value, double ppm)
 {
@@ -652,7 +651,7 @@ Utils::ppm(double value, double ppm)
 
 /*!
 \brief Returns \a value incremented by the matching \a ppm part.
- */
+*/
 double
 Utils::addPpm(double value, double ppm)
 {
@@ -662,7 +661,7 @@ Utils::addPpm(double value, double ppm)
 
 /*!
 \brief Returns \a value decremented by the matching \a ppm part.
- */
+*/
 double
 Utils::removePpm(double value, double ppm)
 {
@@ -671,7 +670,7 @@ Utils::removePpm(double value, double ppm)
 
 /*!
 \brief Return the delta corresponding to \a value and resolution \a res.
- */
+*/
 double
 Utils::res(double value, double res)
 {
@@ -680,7 +679,7 @@ Utils::res(double value, double res)
 
 /*!
 \brief Returns \a value incremented by the matching \a res part.
- */
+*/
 double
 Utils::addRes(double value, double res)
 {
@@ -689,7 +688,7 @@ Utils::addRes(double value, double res)
 
 /*!
 \brief Returns \a value decremented by the matching \a res part.
- */
+*/
 double
 Utils::removeRes(double value, double res)
 {
@@ -702,7 +701,7 @@ Utils::removeRes(double value, double res)
 \brief Returns a string representing the \a ptr address location.
 
 \sa stringAsPointer
- */
+*/
 template <typename T>
 QString
 Utils::pointerAsString(T *ptr)
@@ -718,7 +717,7 @@ Utils::pointerAsString(T *ptr)
 the pointer.
 
 \sa pointerAsString()
- */
+*/
 template <typename T>
 T *
 Utils::stringAsPointer(const QString &str)
@@ -732,7 +731,7 @@ Utils::stringAsPointer(const QString &str)
 /*!
 \brief Returns a string holding the the file path to the configuration settings
 for application \a module_name.
- */
+*/
 QString
 Utils::craftConfigSettingsFilePath(const QString &module_name)
 {
@@ -757,7 +756,7 @@ Utils::craftConfigSettingsFilePath(const QString &module_name)
 contents or 1 if theirs contents differ.
 
 Returns -1 if any file could not be opened.
- */
+*/
 int
 Utils::testDiffBetweenTwoTextFiles(const QString &file_path_1,
                                    const QString &file_path_2)
@@ -792,7 +791,7 @@ Utils::testDiffBetweenTwoTextFiles(const QString &file_path_1,
 /*!
 \brief Returns a string obtained by concatenating all the strings in the \a
 error_list container. Each string is separated from the other with \a separator.
- */
+*/
 QString
 Utils::joinErrorList(const ErrorList &error_list, const QString &separator)
 {
@@ -894,7 +893,7 @@ Utils::isProgramRunning(const QString &program_name)
 #endif
     }
 
-    // Fallback to platform-specific methods if QProcess fails
+// Fallback to platform-specific methods if QProcess fails
 #ifdef Q_OS_WIN
   return isProcessRunningInWindows(program_name);
 #elif defined(Q_OS_LINUX)
