@@ -590,20 +590,20 @@ This enum specifies how the peak shape needs to be computed.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::massPeakShapeType
+\variable MsXpS::libXpertMassCore::massPeakShapeTypeMap
 \ingroup Globals
 
 \brief Map relating each \l{MassPeakShapeType} member to a corresponding textual
 representation.
 */
-std::map<Enums::MassPeakShapeType, QString> massPeakShapeType{
+std::map<Enums::MassPeakShapeType, QString> massPeakShapeTypeMap{
   {Enums::MassPeakShapeType::NOT_SET, "NOT_SET"},
   {Enums::MassPeakShapeType::GAUSSIAN, "GAUSSIAN"},
   {Enums::MassPeakShapeType::LORENTZIAN, "LORENTZIAN"}};
 
 
 /*!
-\enum  MsXpS::libXpertMassCore::MassPeakWidthLogic
+\enum  MsXpS::libXpertMassCore::Enums::MassPeakWidthLogic
 \ingroup Globals
 
 This enum specifies how the peak shape needs to be computed.
@@ -619,17 +619,67 @@ the instrument.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::massPeakWidthLogic
+\variable MsXpS::libXpertMassCore::massPeakWidthLogicMap
 \ingroup Globals
 
 \brief Map relating each \l{MassPeakWidthLogic} member to a corresponding
 textual representation.
 */
-std::map<Enums::MassPeakWidthLogic, QString> massPeakWidthLogic{
+std::map<Enums::MassPeakWidthLogic, QString> massPeakWidthLogicMap{
   {Enums::MassPeakWidthLogic::NOT_SET, "NOT_SET"},
   {Enums::MassPeakWidthLogic::FWHM, "FWHM"},
   {Enums::MassPeakWidthLogic::RESOLUTION, "RESOLUTION"}};
 
+/*!
+\enum MsXpS::libXpertMassCore::Enums::MassDataType
+\ingroup Globals
+
+This enum type specifies the kind of mass data that are encoded in a CBOR
+container.
+
+\value NOT_SET
+       The mass data type is not set
+
+\value MASS_SPECTRUM
+       The mass data type is a mass spectrum
+
+\value DRIFT_SPECTRUM
+       The mass data type is a drift spectrum (ion mobility data)
+
+\value TIC_CHROMATOGRAM
+       The mass data type is total ion current chromatogram
+
+\value XIC_CHROMATOGRAM
+       The mass data type is an extract ion current chromatogram
+
+\value MZ_RT_COLORMAP
+       The mass data type is an MZ/RT color map
+
+\value DT_RT_COLORMAP
+       The mass data type is a DT/RT color map
+
+\value DT_MZ_COLORMAP
+       The mass data type is DT/MZ color map
+
+\omitvalue LAST
+ */
+
+/*!
+\brief Map relating each \l{
+  MassDataType} member to a corresponding textual representation.
+  */
+std::map<Enums::MassDataType, QString> massDataTypeMap{
+  {Enums::MassDataType::NOT_SET, "NOT_SET"},
+  {Enums::MassDataType::MASS_SPECTRUM, "MASS_SPECTRUM"},
+  {Enums::MassDataType::DRIFT_SPECTRUM, "DRIFT_SPECTRUM"},
+  {Enums::MassDataType::TIC_CHROMATOGRAM, "TIC_CHROMATOGRAM"},
+  {Enums::MassDataType::XIC_CHROMATOGRAM, "XIC_CHROMATOGRAM"},
+  {Enums::MassDataType::MZ_RT_COLORMAP, "MZ_RT_COLORMAP"},
+  {Enums::MassDataType::DT_RT_COLORMAP, "DT_RT_COLORMAP"},
+  {Enums::MassDataType::DT_MZ_COLORMAP, "DT_MZ_COLORMAP"},
+  {Enums::MassDataType::LAST, "LAST"}};
+
+
 /*!
 \brief Number of decimal places after the decimal symbol for atom masses.
 \ingroup Globals
@@ -661,133 +711,5 @@ int PKA_PH_PI_DEC_PLACES = 2;
     Synonym for std::vector<QString> ErrorList.
 */
 
-
-//! Produce a shortened version of a string.
-/*!
- * Often, it is necessary to display in a graphical user interface a very long
- * string that cannot fit in the provided widget. This function returns a
- * shortened version of the input string.
- *
- * For example, "Interesting bits of information are often lost where there are
- * too many details", becomes "Interes...details".
- *
- * \param text reference to the string to be shortened
- * \param charsLeft number of characters to be left at the left of the
- * elision string
- * \param charsRight number of characters to be left at the right of the
- * elision string
- * \param delimitor string to use as the elision delimitor
- */
-QString
-elideText(const QString &text,
-          int charsLeft,
-          int charsRight,
-          const QString &delimitor)
-{
-  // We want to elide text. For example, imagine we have text = "that
-  // is beautiful stuff", with charsLeft 4 and charsRight 4 and
-  // delimitor "...". Then the result would be "that...tuff"
-
-  if(charsLeft < 1 || charsRight < 1)
-    {
-      return text;
-    }
-
-  int size = text.size();
-
-  // If the text string is already too short, no need to elide
-  // anything.
-  if((charsLeft + charsRight + delimitor.size()) >= size)
-    {
-      return text;
-    }
-
-  QString result = text.left(charsLeft);
-  result.append(delimitor);
-  result.append(text.right(charsRight));
-
-  return result;
-}
-
-//! Convert a very long text to a paragraph.
-/*!
- * When a text string is too long to be displayed in a line of reasonable
- * length, insert newline characters at positions calculated to yield a
- * paragraph of a given width.
- *
- * The text is left-justified with the most fitting line size possible.
- *
- * \param text string to be converted to a paragraph (a stanza)
- * \param width width in characters of the stanza
- * \return a new string with the stanzified text
- */
-QString
-stanzify(const QString &text, int width)
-{
-  QString result = text;
-
-  // First, replace all the existing newline chars with spaces.
-
-  result = result.replace("\n", " ");
-
-  int iter = width;
-
-  // Then, iterate in the obtained string and every width characters try to
-  // insert a newline character by iterating back to the left and searching
-  // for a space.
-
-  for(; iter < result.size(); iter += width)
-    {
-      // Now iterate in reverse and search for a space where to insert a
-      // newline
-
-      int jter = iter;
-
-      for(; jter >= 0; --jter)
-        {
-          if(result.at(jter) == ' ')
-            {
-              result[jter] = '\n';
-              break;
-            }
-        }
-    }
-
-  return result;
-}
-
-//! Convert a very long text to paragraphs.
-/*!
- * When a text string is too long to be displayed in a line of reasonable
- * length, insert newline characters at positions calculated to yield a
- * paragraph of a given width.
- *
- * The text is left-justified with the most fitting line size possible.
- *
- * \param text string to be converted to a paragraph (a stanza)
- * \param width width in characters of the stanza
- * \return a new string with the stanzified text
- */
-QString
-stanzifyParagraphs(const QString &text, int width)
-{
-  QString result;
-
-  QStringList paragraphList = text.split("\n");
-
-  for(int iter = 0; iter < paragraphList.size(); ++iter)
-    {
-      QString line = paragraphList.at(iter);
-
-      QString stanzifiedLine = stanzify(line, width);
-
-      result.append(stanzifiedLine);
-      result.append("\n");
-    }
-
-  return result;
-}
-
-
 } // namespace libXpertMassCore
 } // namespace MsXpS
