@@ -116,8 +116,7 @@ The isotopic cluster is generated starting from a Formula.
 */
 
 /*!
-\variable
-MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_windowDescription
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_windowDescription
 
 \brief The text to be used for the window title.
 */
@@ -139,8 +138,7 @@ responsible for its ionization.
 */
 
 /*!
-\variable
-MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_normalizeIntensity
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_normalizeIntensity
 
 \brief The intensity value that the most intense peak in the cluster should
 have.
@@ -149,8 +147,7 @@ All the other peaks intensities are normalized against this value.
 */
 
 /*!
-\variable
-MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_maxSummedProbability
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_maxSummedProbability
 
 \brief The sum of all the intensities of the cluster peaks should not exceed
 this value.
@@ -179,37 +176,33 @@ peak centroids.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataLibrary
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataLibrary
 
 \brief The isotopic data from the IsoSpec library tables.
 */
 
 /*!
-\variable
-MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataUserConfig
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataUserConfig
 
 \brief The isotopic data from the IsoSpec-like library tables as modified by
 the user.
 */
 
 /*!
-\variable
-MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataUserManualConfig
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataUserManualConfig
 
 \brief The isotopic data from the user's manual configuration.
 */
 
 /*!
-\variable
-MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::mpa_libraryStaticTableViewModel
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::mpa_libraryStaticTableViewModel
 
 \brief The table view model that manages the library static IsoSpec standard
 data.
 */
 
 /*!
-\variable
-MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::mpa_userStaticTableViewModel
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::mpa_userStaticTableViewModel
 
 \brief The table view model that manages the library user-modified IsoSpec
 standard data.
@@ -223,8 +216,7 @@ isotopic cluster is later shaped into a mass spectrum.
 */
 
 /*!
-\variable
-MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_clusterGenerator
+\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_clusterGenerator
 
 \brief The isotopic cluster generator that will be used for the computations.
 */
