@@ -90,7 +90,8 @@ obtained shapes are combined into a single mass spectrum.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::mp_massPeakShaperConfigWidget
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::mp_massPeakShaperConfigWidget
 
 \brief The widget where the mass peak shaping process configuration is done..
 */
@@ -140,7 +141,8 @@ be traced.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::m_mzIntegrationParams
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::m_mzIntegrationParams
 
 \brief The mass spectrum combination parameters (size of the bins, for example).
 */
@@ -153,7 +155,8 @@ with at half maximum values to and from resolving power values.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::m_normalizingIntensity
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::m_normalizingIntensity
 
 \brief The intensity value that the most intense peak in the cluster should
 have.
@@ -222,7 +225,6 @@ IsotopicClusterShaperDlg::IsotopicClusterShaperDlg(
   setWindowTitle(QString("%1 - %2").arg(applicationName).arg(description));
 }
 
-
 /*!
 \brief Constructs a IsotopicClusterShaperDlg instance.
 
@@ -268,7 +270,8 @@ IsotopicClusterShaperDlg::IsotopicClusterShaperDlg(
 }
 
 /*!
-\brief Upon closing of the dialog window (unused \a event), writes the settings
+\fn IsotopicClusterShaperDlg::closeEvent(QCloseEvent *event)
+Upon closing of the dialog window (unused \a event), writes the settings
 to the application configuration file.
 */
 void
@@ -276,7 +279,8 @@ IsotopicClusterShaperDlg::closeEvent(QCloseEvent *event)
 {
   Q_UNUSED(event)
   // qDebug();
-  writeSettings(libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+  writeSettings(
+    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
 }
 
 /*!
@@ -284,7 +288,8 @@ IsotopicClusterShaperDlg::closeEvent(QCloseEvent *event)
 */
 IsotopicClusterShaperDlg::~IsotopicClusterShaperDlg()
 {
-  writeSettings(libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+  writeSettings(
+    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
   delete mp_ui;
 }
 
@@ -296,8 +301,8 @@ The saved configuration is read from the file to set back the dialog window in
 the same status.
 */
 void
-IsotopicClusterShaperDlg::writeSettings(const QString
-&config_settings_file_path)
+IsotopicClusterShaperDlg::writeSettings(
+  const QString &config_settings_file_path)
 {
   // qDebug();
 
@@ -315,7 +320,6 @@ IsotopicClusterShaperDlg::writeSettings(const QString
   settings.endGroup();
 }
 
-
 /*!
 \brief Reads the settings of this dialog window from the application
 configuration file (\a config_settings_file_path).
@@ -361,17 +365,18 @@ IsotopicClusterShaperDlg::setupDialog()
   // Trasmit the config member object reference so that it can be modified by
   // the configuration widget.
   mp_massPeakShaperConfigWidget =
-    new MassPeakShaperConfigWidget(&m_config, this);
+    new MassPeakShaperConfigWidget(m_config, this);
   v_box_layout_p->addWidget(mp_massPeakShaperConfigWidget);
 
   mp_ui->peakShapeConfigFrame->setLayout(v_box_layout_p);
 
-  // Set the message timer to be singleShot. This time is used to erase the text shown in the message line edit widget after 3 seconds.
+  // Set the message timer to be singleShot. This time is used to erase the text
+  // shown in the message line edit widget after 3 seconds.
   msp_msgTimer->setInterval(3000);
   msp_msgTimer->setSingleShot(true);
-  connect(msp_msgTimer.get(),
-          &QTimer::timeout,
-          [this] (){ mp_ui->messageLineEdit->setText("");});
+  connect(msp_msgTimer.get(), &QTimer::timeout, [this]() {
+    mp_ui->messageLineEdit->setText("");
+  });
 
   connect(mp_ui->normalizationGroupBox,
           &QGroupBox::toggled,
@@ -400,12 +405,14 @@ IsotopicClusterShaperDlg::setupDialog()
 
   // The values above are actually set in readSettings (with default values if
   // missing in the config settings.)
-  readSettings(libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+  readSettings(
+    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
 
 
   // Always start the dialog with the first page of the tab widget,
   // the input data page.
-  mp_ui->tabWidget->setCurrentIndex(static_cast<int>(TabWidgetPage::INPUT_DATA));
+  mp_ui->tabWidget->setCurrentIndex(
+    static_cast<int>(TabWidgetPage::INPUT_DATA));
 
   // Throughout of *this* dialog window, the normalization factor
   // for the peak shapes (Gaussian, specifically) is going to be 1.
@@ -418,7 +425,8 @@ IsotopicClusterShaperDlg::setupDialog()
   connect(mp_ui->checkParametersPushButton,
           &QPushButton::clicked,
           this,
-          &IsotopicClusterShaperDlg::checkParameters);
+          qOverload<>(
+            &IsotopicClusterShaperDlg::checkParameters));
 
   connect(mp_ui->runPushButton,
           &QPushButton::clicked,
@@ -509,10 +517,12 @@ IsotopicClusterShaperDlg::fillInThePeakShapers()
 }
 
 /*!
-\brief Checks that the configuration parameters are correct..
+\brief Checks that the configuration parameters are correct. Any encountered
+error is appended to \a error_list.
 */
 bool
-IsotopicClusterShaperDlg::checkParameters()
+IsotopicClusterShaperDlg::checkParameters(
+  libXpertMassCore::ErrorList &error_list)
 {
   qDebug();
 
@@ -526,21 +536,25 @@ IsotopicClusterShaperDlg::checkParameters()
   // Remove all text in the results text edit widget.
   mp_ui->resultPlainTextEdit->clear();
 
+  QString msg;
+
   // Make sure we have some (mz,i) values to crunch.
   if(!m_isotopicCluster.size())
     {
-      message("There are no centroid peaks to process");
-      qDebug("There are no centroid peaks to process");
-
+      msg = "There are no centroid peaks to process.\n";
+      message(msg);
+      error_list.append(msg);
+      qDebug() << msg;
       return false;
     }
 
   if(m_referencePeakMz <= 0)
     {
-      message(
-        "The reference peak m/z value is not set. Please enter one m/z value.");
-      qDebug() << "The reference peak m/z value is not set";
-
+      msg =
+        "The reference peak m/z value is not set. Please enter one m/z value.";
+      message(msg);
+      error_list.append(msg);
+      qDebug() << msg;
       return false;
     }
 
@@ -550,21 +564,32 @@ IsotopicClusterShaperDlg::checkParameters()
   // m/z has charge at the denominator!
   if(charge <= 0)
     {
-      message("The ion charge must be >= 1", 6000);
+      msg = "The ion charge must be >= 1";
+      message(msg, 6000);
+      error_list.append(msg);
+      qDebug() << msg;
       return false;
     }
 
   /////////////////// Ask the widget to perform the check ///////////////////
 
-  libXpertMassCore::ErrorList error_list;
+  libXpertMassCore::ErrorList widget_error_list;
 
   if(!mp_massPeakShaperConfigWidget->checkParameters(&error_list))
     {
-      message("There were errors in the configuration: " + libXpertMassCore::Utils::joinErrorList(error_list, "\n"), 10000);
+      msg =
+        QString("There were errors in the configuration:\n%1")
+          .arg(libXpertMassCore::Utils::joinErrorList(widget_error_list, "\n"));
+      message(msg, 100000);
+      error_list.append(msg);
+      qDebug() << msg;
       return false;
     }
 
   // No errors ? Then output the configuration.
+  qDebug().noquote() << mp_massPeakShaperConfigWidget->getConfig();
+
+  m_config.initialize(*mp_massPeakShaperConfigWidget->getConfig());
 
   QString text = m_config.toString();
 
@@ -573,14 +598,16 @@ IsotopicClusterShaperDlg::checkParameters()
   mp_ui->logPlainTextEdit->appendPlainText(text);
 
   // Finally do a resolve of all the config bits to something actually useful.
+  libXpertMassCore::ErrorList resolve_error_list;
 
-  if(!m_config.resolve())
+  if(!m_config.resolve(resolve_error_list))
     {
-      message(
-        "Failed to finally resolve the configuration. Check the LOG tab for "
-        "details.");
-      qDebug().noquote() << text;
-
+      msg = QString("Failed to finally resolve the configuration:\n%1")
+              .arg(libXpertMassCore::Utils::joinErrorList(resolve_error_list,
+                                                          "\n"));
+      message(msg, 6000);
+      error_list.append(msg);
+      qDebug() << msg;
       return false;
     }
 
@@ -592,7 +619,7 @@ IsotopicClusterShaperDlg::checkParameters()
     {
       QMessageBox::warning(
         0,
-        tr("mineXpert: Peak shaper (Gaussian or Lorentzian)"),
+        tr("Peak shaper (Gaussian or Lorentzian)"),
         tr("Please, insert at least one (m/z i) pair in the following "
            "format:\n\n"
            "<number><separator><number>\n\n"
@@ -613,7 +640,6 @@ IsotopicClusterShaperDlg::checkParameters()
 
   mp_ui->logPlainTextEdit->appendPlainText(m_config.toString());
 
-
   message("The configuration validated fine. Check the LOG tab for details.");
 
   // At this point we'll have some things to report to the LOG tab,
@@ -624,6 +650,17 @@ IsotopicClusterShaperDlg::checkParameters()
   return true;
 }
 
+/*!
+\brief Checks that the configuration parameters are correct.
+\sa checkParameters(libXpertMassCore::ErrorList &error_list)
+*/
+bool
+IsotopicClusterShaperDlg::checkParameters()
+{
+  libXpertMassCore::ErrorList error_list;
+  return checkParameters(error_list);
+}
+
 /*!
 \brief Set \a message to the message line edit widget with \a timeout.
 
@@ -646,20 +683,15 @@ IsotopicClusterShaperDlg::run()
 {
   qDebug();
 
-  if(!checkParameters())
+  libXpertMassCore::ErrorList error_list;
+
+  if(!checkParameters(error_list))
     {
       QMessageBox::warning(
         0,
-        tr("mineXpert: Peak shaper (Gaussian or Lorentzian)"),
-        tr("Please, insert at least one (m/z i) pair in the following "
-           "format:\n\n"
-           "<number><separator><number>\n\n"
-           "With <separator> being any non numerical character \n"
-           "(space or non-'.' punctuation, for example).\n\n"
-           "Once the data have been pasted in the edit widget, click the "
-           "'Import from text' button above.\n"
-           "Also, make sure that you fill-in the resolution or the FWHM "
-           "value and the ion charge."),
+        tr("Isotopic cluster shaper"),
+        QString("The parameters check failed with errors:\n%1")
+          .arg(libXpertMassCore::Utils::joinErrorList(error_list, "\n")),
         QMessageBox::Ok);
 
       return;
@@ -734,8 +766,8 @@ IsotopicClusterShaperDlg::run()
             maxMz,
             pappso::MzIntegrationParams::BinningType::ARBITRARY,
             pappso::PrecisionFactory::getDaltonInstance(bin_size),
-            /*binSizeDivisor, 1 = no-op*/1,
-            /*decimalPlacesr*/-1,
+            /*binSizeDivisor, 1 = no-op*/ 1,
+            /*decimalPlacesr*/ -1,
             true);
         }
       else
@@ -1078,7 +1110,6 @@ IsotopicClusterShaperDlg::normalizingIntensityValueChanged()
   m_normalizingIntensity = mp_ui->normalizingIntensitySpinBox->value();
 }
 
-
 /*!
 \brief Signals that the the normalization group box was toggled.
 
