@@ -314,17 +314,10 @@ MassPeakShaperConfigWidget::setupWidget()
           this,
           qOverload<>(&MassPeakShaperConfigWidget::checkParameters));
 
-#if defined(MXE) || (QT_VERSION < QT_VERSION_CHECK(6, 8, 0))
-  connect(mp_ui->noBinsCheckBox,
-          &QCheckBox::stateChanged,
-          this,
-          &MassPeakShaperConfigWidget::noBinsCheckBoxStateChanged);
-#else
   connect(mp_ui->noBinsCheckBox,
           &QCheckBox::checkStateChanged,
           this,
           &MassPeakShaperConfigWidget::noBinsCheckBoxStateChanged);
-#endif
 }
 
 /*!
@@ -783,11 +776,13 @@ MassPeakShaperConfigWidget::setParameters(
   libXpertMassCore::Enums::MassPeakShapeType mass_peak_shape_type,
   double resolution,
   double fwhm,
-  int bin_size_divisor)
+  int bin_size_divisor,
+  bool should_create_bins)
 {
   mp_ui->referenceMassLineEdit->setText(QString::number(reference_peak_mz));
   mp_ui->pointCountSpinBox->setValue(point_count);
-  if(mass_peak_shape_type == libXpertMassCore::Enums::MassPeakShapeType::GAUSSIAN)
+  if(mass_peak_shape_type ==
+     libXpertMassCore::Enums::MassPeakShapeType::GAUSSIAN)
     mp_ui->gaussianRadioButton->setChecked(true);
   else
     mp_ui->gaussianRadioButton->setChecked(false);
@@ -817,6 +812,9 @@ MassPeakShaperConfigWidget::setParameters(
     bin_size_divisor = 6;
 
   mp_ui->fmwhToBinSizeDivisorSpinBox->setValue(bin_size_divisor);
+
+  mp_ui->noBinsCheckBox->setCheckState(should_create_bins ? Qt::Unchecked
+                                                          : Qt::Checked);
 }
 
 void
@@ -845,16 +843,19 @@ MassPeakShaperConfigWidget::checkParameters()
 \overload
 \brief Checks that all the parameters are consistent and correct.
 
-If errors occurs, they ware added to \a error_list.
+If errors occurs, they are added to \a error_list_p.
 
 Returns true is the check succeeded, false otherwise.
 
 \sa checkParameters()
 */
 bool
-MassPeakShaperConfigWidget::checkParameters(libXpertMassCore::ErrorList *error_list_p)
+MassPeakShaperConfigWidget::checkParameters(
+  libXpertMassCore::ErrorList *error_list_p)
 {
-  int initial_error_count = error_list_p->size();
+  int initial_error_count = 0;
+  if(error_list_p)
+    initial_error_count = error_list_p->size();
 
   QString msg;
 
@@ -872,7 +873,8 @@ MassPeakShaperConfigWidget::checkParameters(libXpertMassCore::ErrorList *error_l
     {
       msg = "Please fill in the reference peak m/z value.";
       message(msg);
-      error_list_p->push_back(msg);
+      if(error_list_p != nullptr)
+        error_list_p->push_back(msg);
       qDebug() << msg;
     }
 
@@ -887,7 +889,8 @@ MassPeakShaperConfigWidget::checkParameters(libXpertMassCore::ErrorList *error_l
     {
       msg = "The number of points allowed to craft the shape is too small.";
       message(msg);
-      error_list_p->push_back(msg);
+      if(error_list_p != nullptr)
+        error_list_p->push_back(msg);
       qDebug() << msg;
     }
   else
@@ -912,7 +915,8 @@ MassPeakShaperConfigWidget::checkParameters(libXpertMassCore::ErrorList *error_l
     {
       msg = "Please, fix the Resolution / FWHM value (one or the other).";
       message(msg);
-      error_list_p->push_back(msg);
+      if(error_list_p != nullptr)
+        error_list_p->push_back(msg);
       qDebug() << msg;
 
       // By default we favor the resolving power-based calculation.
@@ -938,7 +942,8 @@ MassPeakShaperConfigWidget::checkParameters(libXpertMassCore::ErrorList *error_l
         {
           msg = "Failed to compute FWHM starting from resolution.";
           message(msg);
-          error_list_p->push_back(msg);
+          if(error_list_p != nullptr)
+            error_list_p->push_back(msg);
           qDebug() << msg;
 
           // By default we favor the resolving power-based calculation.
@@ -971,7 +976,8 @@ MassPeakShaperConfigWidget::checkParameters(libXpertMassCore::ErrorList *error_l
         {
           msg = "Failed to compute the resolution.";
           message(msg);
-          error_list_p->push_back(msg);
+          if(error_list_p != nullptr)
+            error_list_p->push_back(msg);
           qDebug() << msg;
 
           // By default we favor the resolving power-based calculation.
@@ -998,31 +1004,38 @@ MassPeakShaperConfigWidget::checkParameters(libXpertMassCore::ErrorList *error_l
     {
       msg = "Failed to compute the bin size.";
       message(msg);
-      error_list_p->push_back(msg);
+      if(error_list_p != nullptr)
+        error_list_p->push_back(msg);
       qDebug() << msg;
     }
 
   // Craft a string describing the whole set of params as we have been
   // working on them in the configuration instance.
 
-  QString info = mp_config->toString();
+  QString mass_peak_shaper_config_text = mp_config->toString();
 
-  // qDebug().noquote() << "Configuration:" << info;
+  qDebug().noquote() << "Configuration:" << mass_peak_shaper_config_text;
 
-  if(!mp_config->resolve())
+  libXpertMassCore::ErrorList error_list;
+
+  if(!mp_config->resolve(error_list))
     {
-      msg = "Failed to finally resolve the configuration.";
+      msg =
+        QString("Failed to finally resolve the configuration with errors:\n%1")
+          .arg(libXpertMassCore::Utils::joinErrorList(error_list, "\n"));
       message(msg);
-      error_list_p->push_back(msg);
+      if(error_list_p != nullptr)
+        error_list_p->push_back(msg);
       qDebug() << msg;
     }
 
-  if(error_list_p->size() > initial_error_count)
+  if(error_list_p != nullptr && error_list_p->size() > initial_error_count)
     {
-      QMessageBox::warning(this,
-                           "Mass peak shaper configuration - errors:",
-                           libXpertMassCore::Utils::joinErrorList(*error_list_p, "\n"),
-                           QMessageBox::Ok);
+      QMessageBox::warning(
+        this,
+        "Mass peak shaper configuration - errors:",
+        libXpertMassCore::Utils::joinErrorList(*error_list_p, "\n"),
+        QMessageBox::Ok);
 
       return false;
     }
@@ -1035,6 +1048,12 @@ MassPeakShaperConfigWidget::checkParameters(libXpertMassCore::ErrorList *error_l
   return true;
 }
 
+const libXpertMassCore::MassPeakShaperConfig *
+MassPeakShaperConfigWidget::getConfig() const
+{
+  return mp_config;
+}
+
 void
 MassPeakShaperConfigWidget::registerJsConstructor(QJSEngine *engine)
 
